@@ -1,12 +1,17 @@
       program mainsci
+c     Copyright INRIA
       character*40 arg,display
-      character*256 pname 
+      character*256 pname, path
       integer nos,now,idisp,mem
       integer p1,p2
+      integer lpname, ldisp
       common /comnos/nos,mem
+      common /starfi/path
       data now,idisp /0,0/
+      data lpname,ldisp /256,40/
       nos=0
       mem=0
+      path=' '
       nargs = iargc()
       call fgetarg(0,pname)
       i = 0
@@ -35,13 +40,17 @@
          arg=' '
          call fgetarg(i,arg)
          read(arg,'(i10)') mem
+      elseif (arg.eq.'-f') then
+         i=i+1
+         call fgetarg(i,path)         
       endif
       goto 10
  11   continue
       mem=max(mem,180000)
+      if ( nos.eq.0 ) call settmpdir()
       if(now.eq.1) then
          call scilab(nos)
       else
-         call winsci(pname,nos,idisp,display)
+         call winsci(pname,nos,idisp,display,lpname,ldisp)
       endif
       end
