@@ -5,17 +5,19 @@ c     file handling and other i/o
 c     
 c     ====================================================================
 c     
+c     Copyright INRIA
       INCLUDE '../stack.h'
       integer    lch
-      parameter (lch=255)
+      parameter (lch=1024)
       character chaine*(lch)
 c     
-      integer blank,flag,top2,semi,percen,id(nlgh),h(nsiz)
+      integer blank,flag,top2,tops,topk,semi,percen,id(nlgh),h(nsiz)
       integer status,access,form,recl,old,new,scratc,unknow
       integer sequen,direct,forma1,unform
       integer clo,rew,bak,ope,ftyp,fmttyp,mode(2),retu(6),comma,eol
+      integer nocomp
       double precision eps,xxx
-      logical opened
+      logical opened,eptover
       integer iadr,sadr
       character bu1*(bsiz),bu2*(bsiz)
 c
@@ -27,6 +29,7 @@ c
       data unform/988958/
       data clo/12/,ope/24/,rew/27/,bak/11/,last/21/,nclas/29/
       data retu/27,14,29,30,27,23/,comma/52/,eol/99/
+      data nocomp/23/
 c     
       iadr(l)=l+l-1
       sadr(l)=(l/2)+1
@@ -36,23 +39,29 @@ c
          call basout(io,wte,' matio '//buf(1:4))
       endif
 c     
-      if(rstk(pt).eq.902) goto 22
+      tops=top
+c
+      if(int(rstk(pt)/100).ne.9) goto 01
+      if(rstk(pt).eq.902) goto 12
       if(rstk(pt).eq.903) goto 24
       if(rstk(pt).eq.904) goto 57
+      if(rstk(pt).eq.908) goto 203
+      if(rstk(pt).eq.909) goto 16
 c     
 c     functions/fin
 c     
 c     load read  getf exec lib   diary save write print mac  deff rat
 c     1    2     3    4     5     6    7     8     9    10   11   12
-c     file hosts readb writb execstr  disp  getpid getenv
-c     13   14    15    16     17      18     19     20
+c     file hosts readb writb execstr  disp  getpid getenv read4b write4b
+c     13   14    15    16     17      18     19     20     22      23
 c     
 c     
-      goto ( 35,120, 55, 20,130, 27, 30, 60, 25, 160,
-     +     50, 45,140,170,190,180,23,200,205,210,170),fin
+ 01   goto ( 35, 120, 54,10, 130,27, 30,60, 25, 160,
+     +       50, 45, 140,170,190,180,20,200,205,210,
+     +       170,220,230),fin
 c     
 c     exec
- 20   continue
+ 10   continue
       lw=lstk(top+1)
       il=iadr(lstk(top))
       if(rhs.gt.2.or.rhs.lt.1) then
@@ -67,6 +76,7 @@ c     opening file
       top2=top
       top = top-rhs+1
       il=iadr(lstk(top))
+      if(istk(il).eq.11.or.istk(il).eq.13) goto 15
       mode(1)=-1
       mode(2)=0
       call v2unit(top,mode,lunit,opened,ierr)
@@ -74,13 +84,13 @@ c     opening file
 c     
       flag = 3
       if (sym .eq. semi) flag = 0
-      if(rhs.eq.1) goto 21
+      if(rhs.eq.1) goto 11
       il2=iadr(lstk(top2))
       l=sadr(il2+4)
       flag = int(stk(l))
       if(flag.ge.4) call basout(io,wte,
-     &     'mode pas a pas. entrez des lignes blanches.')
- 21   top=top-1
+     &     'step-by-step mode: enter carriage return to proceed')
+ 11   top=top-1
       pt=pt+1
       pstk(pt)=rio
       rio = lunit
@@ -89,7 +99,7 @@ c
       fin=flag
 c     *call*  macro
       go to 999
- 22   call clunit(-rio,buf,0)
+ 12   call clunit(-rio,buf,mode)
       rio=pstk(pt)
       pt=pt-1
       top=top+1
@@ -97,26 +107,75 @@ c     *call*  macro
       istk(il)=0
       lstk(top+1)=sadr(il+1)
       goto 999
+
+c     exec of a function
+ 15   continue
+      flag = 3
+      if (sym .eq. semi) flag = 0
+      if(rhs.eq.2) then
+         il2=iadr(lstk(top2))
+         l=sadr(il2+4)
+         flag = int(stk(l))
+         if(flag.ge.4) call basout(io,wte,
+     &        'step-by-step mode: enter carriage return to proceed')
+         top=top-1
+      endif
+      rstk(pt)=909
+      icall=5
+c     *call*  macro
+      go to 999
+ 16   pt=pt-1
+      top=top+1
+      il=iadr(lstk(top))
+      istk(il)=0
+      lstk(top+1)=sadr(il+1)
+      goto 999
 c     
 c     execstr
- 23   continue
-      lw=lstk(top+1)
-      il=iadr(lstk(top))
-      if(rhs.ne.1) then
+ 20   continue
+      if(rhs.ne.1.and.rhs.ne.2) then
          call error(39)
          return
       endif
+      if(rhs.eq.2) then
+         rhs=1
+         top=top-1
+         icheck=1
+      else
+         icheck=0
+      endif
+      lw=lstk(top+1)
+      il=iadr(lstk(top))
       if(lhs.gt.1) then
          call error(41)
          return
       endif
       if(istk(il).ne.10) then 
+         if(istk(il).eq.1.and.istk(il+1).eq.0) then
+            istk(il)=0
+            lstk(top+1)=lstk(top)+1
+            return
+         endif
          err=1
          call error(55)
          return
       endif
-      l=il+5+istk(il+1)*istk(il+2)
-      l1=l+istk(l-1)-1
+      n=istk(il+1)*istk(il+2)
+      l=il+5+n
+      if(n.gt.1) then
+c     .  add <eol> at the end of the first n-1 lines
+         i1=n-1
+         do 21 i=n,2,-1
+            ld=l+istk(il+3+i)-1
+            ln=istk(il+4+i)-istk(il+3+i)
+            call icopy(ln,istk(ld),-1,istk(ld+i1),-1)
+            i1=i1-1
+            istk(ld+i1)=eol
+            istk(il+4+i)=istk(il+4+i)+i-1
+ 21      continue 
+      endif
+c     add ",return,<eol>,<eol>" at the end of the last line
+      l1=l-1+istk(l-1)
       istk(l1)=comma
       l1=l1+1
       call icopy(6,retu,1,istk(l1),1)
@@ -133,14 +192,43 @@ c
       pt=pt+1
       pstk(pt)=top
       rstk(pt)=903
+c     error control
+      ids(2,pt)=errct
+      ids(3,pt)=err2
+      ids(4,pt)=err1
+      if(icheck.eq.0) then
+         ids(1,pt)=0
+      else
+         ids(1,pt)=1
+         errct=-900001
+      endif
       icall=5
 c     *call*  macro
       go to 999
  24   continue
-      il=iadr(lstk(top))
-      istk(il)=0
-      lstk(top+1)=lstk(top)+1
+      if(ids(1,pt).eq.1) then
+c     return error number
+         il=iadr(lstk(top))
+         istk(il)=1
+         istk(il+1)=1
+         istk(il+2)=1
+         istk(il+3)=0
+         l=sadr(il+4)
+         stk(l)=err1
+         lstk(top+1)=l+1
+         errct=ids(2,pt)
+         err2=ids(3,pt)
+         err1=ids(4,pt)
+         fun=0
+      else
+         il=iadr(lstk(top))
+         istk(il)=0
+         lstk(top+1)=lstk(top)+1
+         err1=0
+      endif
+
       pt=pt-1
+
       goto 999
 c     
 c     print
@@ -170,12 +258,17 @@ c
       endif
       top=top2
       do 26 i=2,rhs
-         call print(idstk(1,top),top,lunit)
+         tops=top
+         call print(idstk(1,top),tops,lunit)
          top=top-1
  26   continue
       lct(2) = l
       istk(il)=0
-      if(.not.opened) call clunit(-lunit,buf,0)
+      if(.not.opened) then
+         mode(1)=0
+         mode(2)=0
+         call clunit(-lunit,buf,mode)
+      endif
       go to 999
 c     
 c     diary
@@ -200,7 +293,11 @@ c     opening file
       if(ierr.gt.0) return
 
 c     
-      if(wio.ne.0) call clunit(-wio,buf,0)
+      if(wio.ne.0) then
+         mode(1)=0
+         mode(2)=0
+         call clunit(-wio,buf,mode)
+      endif
       if(lunit.eq.0) goto 29
       wio=lunit
       istk(il)=0
@@ -234,6 +331,8 @@ c     opening file
       call v2unit(top,mode,lunit,opened,ierr)
       if(ierr.gt.0) return
 c     
+      call savlod(lunit,id,-1,top)
+      if(err.gt.0) goto 33
       if(rhs.ge.2) then
          k=top2
       else
@@ -247,7 +346,11 @@ c
       if(fin.eq.7) call savlod(lunit,idstk(1,k),0,l)
       k = k-1
       if(k.ge.bot.and.rhs.eq.1 .or. k.gt.top.and.rhs.gt.1) goto 32
-      if(.not.opened) call clunit(-lunit,buf,0)
+ 33   if(.not.opened) then
+         mode(1)=0
+         mode(2)=0
+         call clunit(-lunit,buf,mode)
+      endif
       istk(il)=0
       go to 999
 c     
@@ -272,6 +375,8 @@ c     opening file
       mode(2)=0
       call v2unit(top,mode,lunit,opened,ierr)
       if(ierr.gt.0) return
+      call savlod(lunit,id,-2,top)
+      if(err.gt.0) goto 39
 c     
       if(rhs.gt.1) goto 40
  36   job = lstk(bot) - lstk(top)
@@ -284,7 +389,11 @@ c
       call stackp(id,1)
       top = top + 1
       go to 36
- 39   if(.not.opened) call clunit(-lunit,buf,0)
+ 39   if(.not.opened) then
+         mode(1)=0
+         mode(2)=0
+         call clunit(-lunit,buf,mode)
+      endif
       istk(il)=0
       go to 999
 c     
@@ -313,9 +422,7 @@ c
 c     
 c     rat
  45   continue
-      lw=lstk(top+1)
-      il=iadr(lstk(top))
-      if(rhs.ne.1) then
+      if(rhs.gt.2) then
          call error(42)
          return
       endif
@@ -323,27 +430,33 @@ c     rat
          call error(41)
          return
       endif
-
+      if(rhs.eq.2) then
+         il=iadr(lstk(top))
+         if(istk(il).ne.1) then
+            err=2
+            call error(52)
+            return
+         endif
+         eps=stk(sadr(il+4))
+         top=top-1
+      else
+         eps=1.d-6
+      endif
+      lw=lstk(top+1)
+      il=iadr(lstk(top))
       l=sadr(il+4)
-      eps=1.d-6
-      if (rhs .eq. 1) go to 46
-      top=top-1
-      eps=stk(l)
- 46   il=iadr(lstk(top))
+
+      il=iadr(lstk(top))
       if(istk(il).ne.1) then
-         err=1
-         call error(52)
+         call funnam(ids(1,pt+1),'rat',iadr(lstk(top)))
+         top=tops
+         fun=-1
          return
       endif
       l=sadr(il+4)
       m=istk(il+1)
       n=istk(il+2)
       it=istk(il+3)
-      if(it.ne.0) then
-         err=1
-         call error(52)
-         return
-      endif
       mn=m*n*(it+1)
       
       l2 = l
@@ -389,8 +502,17 @@ c
 c     
 c     deff
  50   continue
-      lw=lstk(top+1)
-      il=iadr(lstk(top))
+      icomp=1
+      if(rhs.eq.3) then
+         ilc=iadr(lstk(top))
+         if(istk(ilc).eq.10) then
+            if(istk(ilc+5+istk(ilc+1)*istk(ilc+2)).eq.nocomp) then
+               icomp=0
+            endif
+         endif
+         rhs=rhs-1
+         top=top-1
+      endif
       if(rhs.ne.2) then
          call error(42)
          return
@@ -399,8 +521,20 @@ c     deff
          call error(41)
          return
       endif
+      lw=lstk(top+1)
+      il=iadr(lstk(top))
       call getfun(0)
       if(err.gt.0) goto 999
+      if(icomp.eq.1) then
+         call dcopy(lstk(top+1)-lstk(top),stk(lstk(top)),1,
+     $       stk(lstk(top-1)),1) 
+         lstk(top)=lstk(top-1)+lstk(top+1)-lstk(top)
+         call putid(idstk(1,top-1),idstk(1,top))
+         top=top-1
+         job=1
+         opened=.true.
+         goto 56
+      endif
       call stackp(idstk(1,top),0)
       top=top-1
       il=iadr(lstk(top))
@@ -409,7 +543,7 @@ c     deff
       goto 999
 c     
 c     getf
- 55   continue
+ 54   continue
       lw=lstk(top+1)
       il=iadr(lstk(top))
       if(rhs.gt.2) then
@@ -429,21 +563,32 @@ c     opening file
       if(ierr.gt.0) return
 c     
       if(rhs.gt.1) then
+         ilc=iadr(lstk(top+1))
          icomp=1
+         if(istk(ilc).eq.10) then
+            if(istk(ilc+5+istk(ilc+1)*istk(ilc+2)).eq.nocomp) then
+               icomp=0
+            endif
+         endif
       else
-         icomp=0
+         icomp=1
       endif
- 56   call getfun(lunit)
+ 55   call getfun(lunit)
       fun=0
       job=fin
-      if(err.gt.0) then
-         if(.not.opened) call clunit(-lunit,buf,0)
+      if(err.gt.0.or.err1.gt.0) then
+
+         if(.not.opened) then
+            mode(1)=0
+            mode(2)=0
+            call clunit(-lunit,buf,mode)
+         endif
          return
       endif
       if(job.lt.0) goto 59
       if(icomp.ne.1) goto 58
 c     procedure de compilation des macros (copie de ce qui est dans matsys)
-      rhs=1
+ 56   rhs=1
       il=iadr(lstk(top))
       l=il+1
       mlhs=istk(l)
@@ -456,12 +601,24 @@ c     procedure de compilation des macros (copie de ce qui est dans matsys)
       pstk(pt)=fin
       fin=lstk(top)
       comp(1)=iadr(lstk(top+1))
+      comp(2)=0
+      comp(3)=0
       rstk(pt)=904
       icall=5
 c     *call* parse  macro
       return
  57   l=ids(1,pt)
       pt=pt-1
+      if(err1.ne.0) then
+         comp(2)=0
+         comp(1)=0
+         il=iadr(lstk(top))
+         istk(il)=0
+         lhs=0
+         err2=err1
+         err1=0
+         return
+      endif
       il=iadr(lstk(top))
       il1=iadr(lstk(top+1))
       n=comp(2)-il1
@@ -473,11 +630,18 @@ c     *call* parse  macro
       rhs=0
 c     
  58   call stackp(idstk(1,top),0)
-      if(job.eq.0) goto 56
+      if(job.eq.0) goto 55
+
 c     
  59   il=iadr(lstk(top))
       istk(il)=0
-      if(.not.opened) call clunit(-lunit,buf,0)
+      comp(1)=0
+      fun=0
+      if(.not.opened) then
+            mode(1)=0
+            mode(2)=0
+            call clunit(-lunit,buf,mode)
+      endif
       goto 999
 c     
 c     --------------
@@ -485,6 +649,7 @@ c     write formatte
 c     --------------
 c     
  60   continue
+      ftyp=0
       lw=lstk(top+1)
       il=iadr(lstk(top))
       if(rhs.gt.4.or.rhs.lt.2) then
@@ -515,21 +680,21 @@ c
       else
          if(istk(il).ne.10) then
             call error(61)
-            return
+            goto 996
          endif
       endif
 c     analyse du format
       if(istk(il).ne.10) then
          err=top2-top+1
          call error(55)
-         return
+         goto 996
       endif
       nc=istk(il+5)-1
       l=il+5+istk(il+1)*istk(il+2)
       ftyp=fmttyp(istk(l),nc)
       if(ftyp.eq.0) then
          call error(49)
-         return
+         goto 996
       endif
       call cvstr(nc,istk(l),buf,1)
       top2=top2-1
@@ -554,11 +719,11 @@ c     analyse des numero d'enregistrement
       if(istk(il+3).ne.0) then
          err=top2-top+1
          call error(52)
-         return
+         goto 996
       endif
       if(fin.lt.0.and.ftyp.ne.1.and.ftyp.ne.2) then
          call error(49)
-         return
+         goto 996
       endif
       m=istk(il+1)
       n=istk(il+2)
@@ -621,7 +786,7 @@ c
 c     acces direct
          if(nb.ne.m) then
             call error(42)
-            return
+            goto 996
          endif
          do 69 i=1,m
             li=l+i-1
@@ -640,11 +805,11 @@ c     ecriture des chaines de caracteres
  70   if(istk(il).ne.10) then
          err=top2-top+1
          call error(55)
-         return
+         goto 996
       endif
       if(fin.lt.0.and.ftyp.ne.4) then
          call error(49)
-         return
+         goto 996
       endif
       n=istk(il+2)*istk(il+1)
       m=istk(il+1)
@@ -653,7 +818,7 @@ c     ecriture des chaines de caracteres
       if(iacces.ne.0) then
          if(nb.ne.m) then
             call error(42)
-            return
+            goto 996
          endif
       endif
       do 77 i=1,n
@@ -714,7 +879,11 @@ c
 c     fin generale de write
  78   il=iadr(lstk(top))
       istk(il)=0
-      if(.not.opened) call clunit(-lunit,buf,mode)
+      if(.not.opened) then
+            mode(1)=0
+            mode(2)=0
+            call clunit(-lunit,buf,mode)
+      endif
       goto 999
 c--------------
 c     read formatte
@@ -749,21 +918,21 @@ c
       else
          if(istk(il).eq.1) then
             call error(61)
-            return
+            goto 996
          endif
       endif
 c     analyse du format
       if(istk(il).ne.10) then
          err=rhs
          call error(55)
-         return
+         goto 996
       endif
       nc=istk(il+5)-1
       l=il+5+istk(il+1)*istk(il+2)
       ftyp=fmttyp(istk(l),nc)
       if(ftyp.eq.0) then
          call error(49)
-         return
+         goto 996
       endif
       call cvstr(nc,istk(l),buf,1)
       top2=top2-1
@@ -773,7 +942,7 @@ c     analyse du format
       if(istk(ilb+3).ne.0) then
          err=top2-top+1
          call error(52)
-         return
+         goto 996
       endif
       nb=istk(ilb+1)*istk(ilb+2)
       lb=sadr(ilb+4)
@@ -781,7 +950,7 @@ c     analyse du format
       err=sadr(ilb+nb)-lstk(bot)
       if(err.gt.0) then
          call error(17)
-         return
+         goto 996
       endif
       do 122 i=1,nb
          istk(ilb+i-1)=int(stk(lb+i-1))
@@ -802,7 +971,11 @@ c     analyse du format
          istk(il+2)=0
          istk(il+3)=0
          lstk(top+1)=sadr(il+4)
-         if(.not.opened) call clunit(-lunit,buf,mode)
+         if(.not.opened) then
+            mode(1)=0
+            mode(2)=0
+            call clunit(-lunit,buf,mode)
+         endif
          goto 999
       endif
 
@@ -829,6 +1002,7 @@ c---- lecture de flottants
       if(iacces.eq.0) then
 c     acces sequentiel
          if(m.gt.0) then
+c     .     nombre de ligne precise
             do 124,i=0,m-1
                call dbasin(ierr,lunit,buf(1:nc),stk(l+i),m,n)
                if(ierr.eq.1) then
@@ -838,38 +1012,46 @@ c     acces sequentiel
                endif
  124        continue
          else
+c     .     nombre de ligne non precise
             i=-1
  1241       i=i+1
             li=l+n*i
             err=li+n-lstk(bot)
             if(err.gt.0) then
                call error(17)
-               return
+               goto 996
             endif
             call dbasin(ierr,lunit,buf(1:nc),stk(li),1,n)
             if(ierr.eq.0) goto 1241
             if(ierr.eq.2) goto 998
             m=i
-            lstk(top+1)=l+m*n
-            err=lstk(top+1)+m*n-lstk(bot)
-            if(err.gt.0) then
-               call error(17)
-               return
+            if(m.ne.0) then
+               if(m.ge.1.and.n.ge.1) then
+                  lstk(top+1)=l+m*n
+                  err=lstk(top+1)+m*n-lstk(bot)
+                  if(err.gt.0) then
+                     call error(17)
+                     return
+                  endif
+                  l1=l+m*n
+                  call dcopy(m*n,stk(l),1,stk(l1),1)
+                  call mtran(stk(l1),n,stk(l),m,n,m)
+                  istk(il+1)=m
+               endif
+            else
+               istk(il+1)=0
+               istk(il+2)=0
             endif
-            l1=l+m*n
-            call dcopy(m*n,stk(l),1,stk(l1),1)
-            call mtran(stk(l1),n,stk(l),m,n,m)
-            istk(il+1)=m
          endif         
       else
 c     acces direct
          if(nb.ne.m) then
             call error(42)
-            return
+            goto 996
          endif
          if(fin.gt.0) then
             call error(61)
-            return
+            goto 996
          endif
          if(m.lt.0) then
             call  error(43)
@@ -882,28 +1064,32 @@ c     acces direct
  125     continue
       endif
       lstk(top+1)=l+m*n
-      if(.not.opened) call clunit(-lunit,buf,mode)
+      if(.not.opened) then
+         mode(1)=0
+         mode(2)=0
+         call clunit(-lunit,buf,mode)
+      endif
       goto 999
 c     
 c---- lecture des chaines de caracteres
  126  if(ftyp.ne.4) then
          call error(49)
-         return
+         goto 996
       endif
       if(n.ne.1) then
          err=iacces-top
          call error(36)
-         return
+         goto 996
       endif
       if(iacces.ne.0) then
          if(nb.ne.m) then
             call error(42)
-            return
+            goto 996
          endif
       endif
       ili=il+4
       if(m.gt.0) then
-c     nombre de ligne a lire precise
+c     .  nombre de ligne a lire precise
          li=ili+m+1
          istk(ili)=1
          do 128 i=1,m
@@ -932,9 +1118,10 @@ c     nombre de ligne a lire precise
          istk(il)=10
          lstk(top+1)=sadr(li)
       else
+c     .  nombre de ligne a lire non precise
          if(iacces.ne.0) then
             call error(43)
-            return
+            goto 996
          endif
          li=ili
          i=-1
@@ -947,7 +1134,7 @@ c     nombre de ligne a lire precise
          err=sadr(li+mn+1)-lstk(bot)
          if(err.gt.0) then
             call error(17)
-            return
+            goto 996
          endif
          call cvstr(mn,istk(li+1),buf(nc+1:),0)
          istk(li)=mn
@@ -955,24 +1142,36 @@ c     nombre de ligne a lire precise
          if(ierr.eq.0) goto 1281
          if(ierr.eq.2) goto 998
          m=i
-         call icopy(li-ili+1,istk(ili),-1,istk(li+2),-1)
-         lis=li+2
-         istk(il)=10
-         istk(il+1)=m
-         istk(il+2)=1
-         istk(ili)=1
-         li=ili+m+1
-         do 1283 j=1,m
-            mn=istk(lis)
-            istk(ili+1)=istk(ili)+mn
-            call icopy(mn,istk(lis+1),1,istk(li),1)
-            lis=lis+mn+1
-            li=li+mn
-            ili=ili+1
- 1283    continue
-         lstk(top+1)=sadr(li+1)
+         if(m.le.0) then
+            istk(il)=1
+            istk(il+1)=0
+            istk(il+2)=0
+            istk(il+3)=0
+            lstk(top+1)=sadr(il+4)
+         else
+            call icopy(li-ili+1,istk(ili),-1,istk(li+2),-1)
+            lis=li+2
+            istk(il)=10
+            istk(il+1)=m
+            istk(il+2)=min(m,1)
+            istk(ili)=1
+            li=ili+m+1
+            do 1283 j=1,m
+               mn=istk(lis)
+               istk(ili+1)=istk(ili)+mn
+               call icopy(mn,istk(lis+1),1,istk(li),1)
+               lis=lis+mn+1
+               li=li+mn
+               ili=ili+1
+ 1283       continue
+            lstk(top+1)=sadr(li+1)
+         endif
+      endif
+      if(.not.opened) then
+         mode(1)=0
+         mode(2)=0
+         call clunit(-lunit,buf,mode)
       endif
-      if(.not.opened) call clunit(-lunit,buf,0)
       goto 999
 
 c     
@@ -1028,7 +1227,9 @@ c     lecture des noms
       m=m+1
       goto 131
  132  continue
-      call clunit(-lunit,' ',0)
+      mode(1)=0
+      mode(2)=0
+      call clunit(-lunit,' ',mode)
 c     tri dans l'ordre alphabetique
       il2=il+1
       err=sadr(il2+(nsiz+1)*m)-lstk(bot)
@@ -1046,7 +1247,7 @@ c     tri dans l'ordre alphabetique
          if(ic.eq.percen) then
             ic=abs(id(2))
          endif
-         ic=ic-9
+         ic=max(1,ic-9)
          istk(ilc+ic)=istk(ilc+ic)+1
          istk(il1)=ic
          il=il+nsiz
@@ -1072,7 +1273,11 @@ c     table des pointeurs
       goto 999
 c     
  139  call error(49)
-      if(.not.opened) call clunit(-lunit,buf,0)
+      if(.not.opened) then
+         mode(1)=0
+         mode(2)=0
+         call clunit(-lunit,buf,mode)
+      endif
       return
 c     
 c     filemgr
@@ -1080,7 +1285,7 @@ c
  140  continue
       lw=lstk(top+1)
       il=iadr(lstk(top))
-      if(lhs.ne.1) then
+      if(lhs.gt.2) then
          call error(41)
          return
       endif
@@ -1167,9 +1372,32 @@ c     path
       lunit=0
       call clunit(lunit,buf(1:mn),mode)
       if(err.gt.0) then
-         buf(mn+1:)=' '
-         call error(err)
-         return
+         if(lhs.eq.1) then
+            buf(mn+1:)=' '
+            call error(err)
+            return
+         else
+           top=top-1
+           il=iadr(lstk(top))
+           istk(il)=1
+           istk(il+1)=0
+           istk(il+2)=0
+           istk(il+3)=0
+           l=sadr(il+4)
+           lstk(top+1)=l+1 
+
+           top=top+1
+           il=iadr(lstk(top))
+           istk(il)=1
+           istk(il+1)=1
+           istk(il+2)=1
+           istk(il+3)=0
+           l=sadr(il+4)
+           stk(l)=err
+           lstk(top+1)=l+1
+           err=0
+           return
+        endif
       endif
       top=top-1
       il=iadr(lstk(top))
@@ -1180,9 +1408,26 @@ c     path
       l=sadr(il+4)
       stk(l)=dble(lunit)
       lstk(top+1)=l+1
+      if(lhs.eq.2) then
+           top=top+1
+           il=iadr(lstk(top))
+           istk(il)=1
+           istk(il+1)=1
+           istk(il+2)=1
+           istk(il+3)=0
+           l=sadr(il+4)
+           stk(l)=0.0d0
+           lstk(top+1)=l+1
+        endif
+
+         
       goto 999
 c     
  150  continue
+      if(lhs.ne.1) then
+         call error(41)
+         return
+      endif
       if(rhs.ne.2) then
          call error(36)
          return
@@ -1197,7 +1442,8 @@ c
       top=top-1
       if(itype.ne.clo) goto 151
 c     close
-      call clunit(-lunit,buf,0)
+      mode(1)=0
+      call clunit(-lunit,buf,mode)
       istk(il)=0
       goto 999
  151  if(itype.ne.rew) goto 152
@@ -1254,18 +1500,13 @@ c
       lc=istk(il+5)-istk(il+4)
       if (lc.gt.0) call cvstr(lc,istk(ilf),buf,1)
       call bashos(buf,lc,ls,ierr)
-      if(ierr.ne.0) then
-         call error(85)
-         return
-      endif
-      if(ls.gt.0) then
-         call cvstr(ls,istk(ilf),buf,0)
-         istk(il+5)=istk(il+4)+ls
-         lstk(top+1)=sadr(il+6+ls)
-      else
-         istk(il)=0
-         lstk(top+1)=lstk(top)+1
-      endif
+      istk(il)=1
+      istk(il+1)=1
+      istk(il+2)=1
+      istk(il+3)=0
+      l=sadr(il+4)
+      stk(l)=ierr
+      lstk(top+1)=l+1
       goto 999
 c     
 c     -------------
@@ -1280,48 +1521,84 @@ c
          return
       endif
 
+      if(rhs.eq.3) then
+         iacces=top
+         ilb=iadr(lstk(iacces))
+         if(istk(ilb+3).ne.0) then
+            err=3
+            call error(52)
+            return
+         endif
+         nb=istk(ilb+1)*istk(ilb+2)
+         lb=sadr(ilb+4)
+         top=top-1
+         rhs=rhs-1
+         mode(1)=110
+      elseif(rhs.eq.2) then
+         mode(1)=100
+         iacces=0
+      else
+         call error(39)
+         return
+      endif
+
+
 c     opening file
       top2 = top
       top = top-rhs+1
       il=iadr(lstk(top))
-      mode(1)=100
       mode(2)=0
       call v2unit(top,mode,lunit,opened,ierr)
       if(ierr.gt.0) return
 c     
       if(lunit.eq.wte) then
          call error(49)
-         return
-      endif
-      if(rhs.ne.2) then
-         call error(39)
-         return
+         goto 996
       endif
       nc=0
       il=iadr(lstk(top2))
       if(istk(il).ne.1) then
          err=2
          call error(53)
-         return
+         goto 996
       endif
       if(istk(il+3).ne.0) then
          err=2
          call error(52)
-         return
+         goto 996
       endif
+
 c     
       m=istk(il+1)
       n=istk(il+2)
       l=sadr(il+4)
-      li=l
-      do 181 i=1,m
-         write(lunit,err=998) (stk(li+(j-1)*m),j=1,n)
-         li=li+1
- 181  continue
+      if(iacces.ne.0) then
+         if(nb.ne.m) then
+            call error(42)
+            goto 996
+         endif
+         call entier(nb,stk(lb),istk(ilb))
+         li=l
+         do 181 i=1,m
+            write(lunit,rec=istk(ilb-1+i),err=998)
+     $           (stk(li+(j-1)*m),j=1,n)
+            li=li+1
+ 181     continue
+      else
+         li=l
+         do 182 i=1,m
+            write(lunit,err=998) (stk(li+(j-1)*m),j=1,n)
+            li=li+1
+ 182     continue
+      endif
 c     
       il=iadr(lstk(top))
       istk(il)=0
-      if(.not.opened) call clunit(-lunit,buf,mode)
+      if(.not.opened) then
+         mode(1)=0
+         mode(2)=0
+         call clunit(-lunit,buf,mode)
+      endif
       goto 999
 c     
 c     ------------
@@ -1335,30 +1612,45 @@ c
          call error(42)
          return
       endif
-      if(rhs.ne.3) then
+      iacces=0
+      mode(2)=0
+      if(rhs.eq.4) then
+         iacces=top
+         ilb=iadr(lstk(iacces))
+         if(istk(ilb+3).ne.0) then
+            err=top
+            call error(52)
+            return
+         endif
+         nb=istk(ilb+1)*istk(ilb+2)
+         lb=sadr(ilb+4)
+         top=top-1
+         rhs=rhs-1
+         mode(1)=-111
+      elseif(rhs.eq.3) then  
+         mode(1)=-101
+      else
          call error(39)
          return
       endif
-
 c     opening file
       top2 = top
       top = top-rhs+1
       il=iadr(lstk(top))
-      mode(1)=-101
-      mode(2)=0
+
       call v2unit(top,mode,lunit,opened,ierr)
       if(ierr.gt.0) return
 c     
       if(lunit.eq.wte) then
          call error(49)
-         return
+         goto 996
       endif
 c     
       il=iadr(lstk(top2))
       if(istk(il).ne.1) then
          err=3
          call error(53)
-         return
+         goto 996
       endif
       if(istk(il+3).ne.0) then
          err=3
@@ -1368,7 +1660,7 @@ c
       if(istk(il+1)*istk(il+2).ne.1) then
          err=3
          call error(89)
-         return
+         goto 996
       endif
       l=sadr(il+4)
       n=int(stk(l))
@@ -1378,20 +1670,26 @@ c
       if(istk(il).ne.1) then
          err=2
          call error(53)
-         return
+         goto 996
       endif
       if(istk(il+3).ne.0) then
          err=2
          call error(52)
-         return
+         goto 996
       endif
       if(istk(il+1)*istk(il+2).ne.1) then
          err=2
          call error(89)
-         return
+         goto 996
       endif
       l=sadr(il+4)
       m=int(stk(l))
+      if(iacces.ne.0) then
+         if(m.ne.nb) then
+            call error(42)
+            goto 996
+         endif
+      endif
 c     
       il=iadr(lstk(top))
       if(m.eq.0.or.n.le.0) then
@@ -1411,39 +1709,54 @@ c
       istk(il+3)=0
 
       if(m.gt.0) then
-         err=l+m*n-lstk(bot)
+         lw=l+m*n
+         if(iacces.ne.0) then
+            ilb=iadr(lw)
+            lw=sadr(ilb+nb)
+         endif
+         err=lw-lstk(bot)
          if(err.gt.0) then
             call error(17)
-            return
+            goto 996
          endif
       endif
 c     
-      if(m.gt.0) then
-         do 191 i=0,m-1
-            read(lunit,end=997,err=998) (stk(l+i+j*m),j=0,n-1)
- 191     continue
+      if(iacces.eq.0) then
+c     .  sequential acces
+         if(m.gt.0) then
+            do 191 i=0,m-1
+               read(lunit,end=997,err=998) (stk(l+i+j*m),j=0,n-1)
+ 191        continue
+         else
+            i=-1
+ 192        i=i+1
+            li=l+n*i
+            err=li+n-lstk(bot)
+            if(err.gt.0) then
+               call error(17)
+               goto 996
+            endif
+            read(lunit,end=193,err=998) (stk(li+j),j=0,n-1)
+            goto 192
+ 193        m=i
+            lstk(top+1)=l+m*n
+            err=lstk(top+1)+m*n-lstk(bot)
+            if(err.gt.0) then
+               call error(17)
+               goto 996
+            endif
+            l1=l+m*n
+            call dcopy(m*n,stk(l),1,stk(l1),1)
+            call mtran(stk(l1),n,stk(l),m,n,m)
+            istk(il+1)=m
+         endif
       else
-         i=-1
- 192     i=i+1
-         li=l+n*i
-         err=li+n-lstk(bot)
-         if(err.gt.0) then
-            call error(17)
-            return
-         endif
-         read(lunit,end=193,err=998) (stk(li+j),j=0,n-1)
-         goto 192
- 193     m=i
-         lstk(top+1)=l+m*n
-         err=lstk(top+1)+m*n-lstk(bot)
-         if(err.gt.0) then
-            call error(17)
-            return
-         endif
-         l1=l+m*n
-         call dcopy(m*n,stk(l),1,stk(l1),1)
-         call mtran(stk(l1),n,stk(l),m,n,m)
-         istk(il+1)=m
+c     .  direct access
+         call entier(nb,stk(lb),istk(ilb))
+         do 194 i=0,m-1
+            read(lunit,rec=istk(ilb+i),err=998)
+     $           (stk(l+i+j*m),j=0,n-1)
+ 194     continue
       endif
       lstk(top+1)=l+m*n
       if(.not.opened) call clunit(-lunit,buf,mode)
@@ -1463,10 +1776,32 @@ c     ----
          return
       endif
       id(1)=0
-      do 201 i=1,rhs
-         call print(id,top,wte)
-         top=top-1
+
+c     loop on variable to display
+      i=1
  201  continue
+      topk=top
+ 202  call print(id,topk,wte)
+      if(topk.eq.0) goto 204
+c     overloaded display call macro
+      if ( eptover(1,psiz)) return
+      rstk(pt)=908
+      pstk(pt)=i
+      ids(1,pt)=rhs
+      icall=5
+c     *call* macro
+      return
+ 203  continue
+      i=pstk(pt)
+      rhs=ids(1,pt)
+      pt=pt-1
+      goto 202
+ 204  continue
+c     next variable to display
+      i=i+1
+      top=top-1
+      if(i.le.rhs) goto 201
+
       top=top+1
       il=iadr(lstk(top))
       istk(il)=0
@@ -1503,57 +1838,23 @@ c     getpid get process id
       goto 999
 c
 c     getenv
-
  210  continue
-      if(rhs.ne.1) then
-         call error(42)
-         return
-      endif
-      if(lhs.gt.1) then
-         call error(41)
-         return
-      endif
-      lw=lstk(top+1)
-      il=iadr(lstk(top))
-
-      if(istk(il).ne.10) then
-         err=1
-         call error(55)
-         return
-      endif
-      if(istk(il+1)*istk(il+2).ne.1) then
-         err=1
-         call error(89)
-         return
-      endif
-      ilf=il+6
-      lc=istk(il+5)-istk(il+4)
-      if (lc.gt.0) call cvstr(lc,istk(ilf),buf,1)
-      call getenvc(ierr,buf(1:lc)//char(0),buf)
-      if(ierr.ne.0) then
-         buf='Undefined environment variable'
-         call error(999)
-         return
-      endif
-      ls=0
- 211  ls=ls+1
-      if(buf(ls:ls).ne.char(0).and.ls.lt.bsiz) goto 211
-      ls=ls-1
-      if(ls.gt.0) then
-         call cvstr(ls,istk(ilf),buf,0)
-         istk(il+5)=istk(il+4)+ls
-         lstk(top+1)=sadr(il+6+ls)
-      else
-         istk(il)=0
-         lstk(top+1)=lstk(top)+1
-      endif
+      call intsgetenv("getenv")
       goto 999
 
+c     read4b      
+ 220  call intread4b
+      goto 999
 
+c     write4b
+ 230  call intwrite4b
+      goto 999
 c     --------------
 c     erreur lecture
 c     --------------
 c     
+ 996  if(.not.opened) call clunit(-lunit,buf,mode)
+      return
  997  err=i
       call error(62)
       if(.not.opened) call clunit(-lunit,buf,mode)
@@ -1572,6 +1873,7 @@ c     v2unit return a  logical unit attached to corresponding file
       INCLUDE '../stack.h'
 c
       logical opened
+      integer mode(2)
       integer iadr,sadr
 c     
       iadr(l)=l+l-1
@@ -1596,6 +1898,18 @@ c
             call error(36)
             return
          endif
+
+
+         kk = abs(mode(1))
+         ifor = kk / 100
+         kk    = kk - 100 *ifor
+         iacc = kk / 10
+         if(mode(2).eq.0.and.iacc.eq.1) then
+            ierr=1
+            call error(242)
+            return
+         endif
+
          mn=istk(il+5)-1
          call cvstr(mn,istk(il+5+istk(il+1)*istk(il+2)),buf,1)
          lunit = 0
@@ -1614,3 +1928,39 @@ c
          return
       endif
       end
+
+      subroutine intsgetenv(fname)
+c     =============================
+c     getenv('varname' [,'rep'])
+       character*(*) fname
+       logical checkrhs,checklhs,getsmat,checkval,cresmat2,bufstore
+       include '../stack.h'
+       rhs = max(0,rhs)
+       lbuf = 1
+       if(.not.checkrhs(fname,1,2)) return
+       if(.not.checklhs(fname,1,1)) return
+       if(.not.getsmat(fname,top,top-rhs+1,m1,n1,1,1,lr1,nlr1)) return
+       if(.not.checkval(fname,m1*n1,1)) return
+       if(.not.bufstore(fname,lbuf,lbufi1,lbuff1,lr1,nlr1)) return
+       if(rhs.eq.2) then
+          if(.not.getsmat(fname,top,top-rhs+2,m2,n2,1,1,lr2,nlr2)) 
+     $         return
+          top=top-1
+       endif
+       nc =bsiz
+       call getenvc(ierr,buf(lbufi1:lbuff1),buf,nc,0)
+       if(ierr.ne.0) then 
+          if (rhs.eq.1) then
+             buf='Undefined environment variable'
+             call error(999)
+          else
+             call copyobj(fname,top+1,top)             
+          endif
+       else
+          if(.not.cresmat2(fname,top,nc,ilrs)) return
+          call cvstr(nc,istk(ilrs),buf,0)
+       endif
+       return
+       end
+c
+
