@@ -1,3 +1,4 @@
+/* Copyright INRIA */
 #include "../machine.h"
 
 /* ip is a pointer to a FORTRAN variable coming from SCILAB
@@ -7,13 +8,14 @@ coming from a C function
    moreover, pointer ip is freed */
 
 void C2F(ccharf)(n,ip,op)
-int *n;
-char **ip;
-int *op;
+     int *n;
+     char **ip;
+     int *op;
 {
   int i = 0;
   if (*n > 0) {
-      cvstr_(n,op,*ip,&i,*n);
+      F2C(cvstr)(n,op,*ip,&i,*n);
       free(*ip);
   }
 }
+
