@@ -1,5 +1,11 @@
+/* Copyright INRIA */
 #include <string.h>
+
+#ifdef __STDC__
+#include <stdlib.h>
+#else
 #include <malloc.h>
+#endif
 
 #include "../machine.h"
 
