@@ -1,7 +1,19 @@
 #include <stdio.h>
+#ifndef __MSC__
 #include <dirent.h>
+#endif
 #include <string.h>
+#ifdef __STDC__
+#include <stdlib.h>
+#else
 #include <malloc.h>
+#endif
+
+#ifdef __MSC__ 
+/** only used for x=dir[1024] **/
+#define  getwd(x) _getcwd(x,1024)
+#endif
+
 
 #include "mysearch.h"
 #include "../machine.h"
@@ -10,11 +22,20 @@
 #define MAXNAM 80
 
 extern double atof();
-extern char* basename();
+extern char* my_basename();
+extern int CheckGraphName();
 extern void cerro();
 extern char* dirname();
 extern char *StripGraph();
 
+typedef int (*PF)();
+
+static int CompString(s1, s2)
+char **s1, **s2;
+{
+  return strcmp((char*)*s1,(char*)*s2);
+}
+
 static char description[2*MAXNAM];
 
 void C2F(loadg)(path,lpath,name,lname,directed,n,tail,head,
@@ -40,8 +61,13 @@ int *default_node_diam,*default_node_border,*default_edge_width;
 int *default_edge_hi_width,*default_font_size;
 int *ndim,*ma;
 {
+  /** #ifdef __MSC__
+  return;
+  #else  **/
   FILE *fg;
+#ifndef __MSC__
   DIR *dirp;
+#endif
   char fname[2 * MAXNAM];
   char line[5 * MAXNAM];
   char strname[MAXNAM], head_name[MAXNAM], tail_name[MAXNAM];
@@ -50,27 +76,28 @@ int *ndim,*ma;
   ENTRY node,*found;
   char dir[1024];
   char *pname;
+  char **lar;
 
   path[*lpath] = '\0';
-
+#ifndef __MSC__ 
   if ((dirp=opendir(path)) != NULL) {
     sprintf(description,"\"%s\" is a directory",path);
     cerro(description);
     closedir(dirp);
     return;
   }
-  
+#endif
   if (dirname(path) == NULL) getwd(dir);
   else strcpy(dir,dirname(path));
-
+#ifndef __MSC__ 
   if ((dirp=opendir(dir)) == NULL) {
     sprintf(description,"Directory \"%s\" does not exist",dir);
     cerro(description);
     return;
   }
   closedir(dirp);
-  
-  pname = StripGraph(basename(path));
+#endif
+  pname = StripGraph(my_basename(path));
 
   *lname = strlen(pname);
 
@@ -80,13 +107,13 @@ int *ndim,*ma;
     return;
   }
   strcpy(*name,pname);
-
+#ifndef __MSC__
   if(!CheckGraphName(*name,dir)) {
     sprintf(description,"Graph file \"%s/%s.graph\" does not exist",dir,*name);
     cerro(description);
     return;
   }
-  
+#endif  
   isize = sizeof(int);
   dsize = sizeof(double);
 
@@ -278,7 +305,34 @@ int *ndim,*ma;
     strcpy(node.data,strname);
     myhsearch(node,ENTER);
   }
-  
+
+  /* check uniqueness of node names */
+  if (*ndim != 1) {
+    if ((lar = (char **)malloc(sizeof(char *) * *ndim)) == NULL) {
+      cerro("Running out of memory");
+      return;
+    }
+    for (i = 0; i < *ndim; i++) lar[i] = (*node_name)[i];
+    qsort((char*)lar,*ndim,sizeof(char*),(PF)CompString);
+    for (i = 0; i < *ndim - 1; i++) {
+      if (!strcmp(lar[i],lar[i+1])) {
+	sprintf(description,
+		"Bad graph file. Node \"%s\" is duplicated",lar[i]);
+	cerro(description);
+	free(lar);
+	return;
+      }
+    }
+    if (!strcmp(lar[*ndim - 2],lar[*ndim - 1])) {
+      sprintf(description,
+	      "Bad graph file. Node \"%s\" is duplicated",lar[*ndim - 2]);
+      cerro(description);
+      free(lar);
+      return;
+    }
+    free(lar);
+  }
+ 
    /* rewind and go to arc description */
   rewind(fg);
   for (i = 0; i < 11; i++)
@@ -337,4 +391,5 @@ int *ndim,*ma;
   }
   myhdestroy();
   fclose(fg);
+  /** #endif**/ /**  __MSC__ **/
 }
