@@ -1,5 +1,12 @@
+#include <stdio.h>
 #include <string.h>
+
+#ifdef __STDC__
+#include <stdlib.h>
+#else
 #include <malloc.h>
+#endif
+
 
 #include "../machine.h"
 
