@@ -1,5 +1,4 @@
-C/MEMBR ADD NAME=WMDSP,SSI=0
-      subroutine wmdsp(xr,xi,nx,m,n,maxc,mode,ll,lunit,cw,iw)
+      subroutine wmdsp(xr,xi,nx,mm,nn,maxc,mode,ll,lunit,cw,iw)
 c!but
 c     wmdsp ecrit une matrice complexe  (ou un scalaire) sous
 c     la forme d'un tableau, avec gestion automatique de
@@ -26,6 +25,7 @@ c     cw : chaine de caracteres de travail de longueur au moins ll
 c     iw : tableau de travail entier de taille au moins egale a
 c          m*n + 2*n
 c
+c     Copyright INRIA
       double precision xr(*),xi(*),a,a1,a2,fact
       integer iw(*),maxc,mode,fl,s,typ
       character cw*(*),sgn*1,dl*1,var*4
@@ -34,6 +34,9 @@ c
       var='i'
       lvar=1
 c
+      m=abs(mm)
+      n=abs(nn)
+
       cw=' '
       write(form(1),130) maxc,maxc-7
       dl=' '
@@ -129,9 +132,17 @@ c
          s=iw(k)
       endif
    21 continue
+      l1=1
       if(fact.ne.1.0d+0) then
-         write(cw(1:12),'(1x,1pd9.1,'' *'')')  1.0d+0/fact
-         call basout(io,lunit,cw(1:12))
+         write(cw(l1:l1+11),'(1x,1pd9.1,'' *'')')  1.0d+0/fact
+         l1=l1+12
+      endif
+      if(mm.lt.0) then
+         write(cw(l1:l1+4),'(''eye *'')') 
+         l1=l1+5
+      endif
+      if(l1.gt.1) then
+         call basout(io,lunit,cw(1:l1-1))
          call basout(io,lunit,' ')
          if(io.eq.-1) goto 99
       endif
