@@ -495,6 +495,25 @@
 #   define  LARGEST_SHORT_INTEGER   SHRT_MAX
 #   define  LARGEST_LONG_INTEGER    LONG_MAX
 #endif
+#ifdef WIN32 
+#   include <limits.h>
+#   include <float.h>
+#   define  MACHINE_RESOLUTION      DBL_EPSILON
+#   define  LARGEST_REAL            DBL_MAX
+#   define  SMALLEST_REAL           DBL_MIN
+/* XXXXX : a v'erifier */ 
+#   define  LARGEST_SHORT_INTEGER   32766
+#   define  LARGEST_LONG_INTEGER    2147483646
+#endif
+#if defined(__MWERKS__)||defined(THINK_C)
+#   include <limits.h>
+#   include <float.h>
+#   define  MACHINE_RESOLUTION      DBL_EPSILON
+#   define  LARGEST_REAL            DBL_MAX
+#   define  SMALLEST_REAL           DBL_MIN
+#   define  LARGEST_SHORT_INTEGER   SHRT_MAX
+#   define  LARGEST_LONG_INTEGER    LONG_MAX
+#endif
 
 #endif /* NOT defined(__STDC__) */
 
@@ -524,4 +543,3 @@
 
 
 
-
