@@ -1,13 +1,15 @@
-      subroutine wful2sp(ma,na,ar,ai,nel,indr,rr,ri)
+      subroutine wful2sp(ma,na,ar,ai,nel,indr,rr,ri,zeror,zeroi)
 c     converts a full matrix to a sparse representation
+c     Copyright INRIA
       double precision ar(ma,na),ai(ma,na),rr(*),ri(*)
+      double precision zeror,zeroi
       integer indr(*)
 c
       nel=0
       do 5 i=1,ma
          ni=0
          do 4 j=1,na
-            if(abs(ar(i,j))+abs(ai(i,j)).ne.0.0d0) then
+            if(ar(i,j).ne.zeror.or.ai(i,j).ne.zeroi) then
                nel=nel+1
                indr(ma+nel)=j
                rr(nel)=ar(i,j)
