@@ -2,6 +2,7 @@
 c
 c ================================== ( Inria    ) =============
 c
+c     Copyright INRIA
       include '../stack.h'
       integer    ierr,n,nout
       character  ligne*(*)
@@ -15,6 +16,6 @@ c
       if (ln.le.0) goto 100
       if(ligne(1:ln).eq.' ') goto 100
       buf=ligne(1:ln)// char(0)
-      call systemc(buf)
+      call systemc(buf,ierr)
   100 continue
       end
