@@ -15,9 +15,9 @@ c ================================== ( inria    ) =============
          call basout(io,wwte,' ')
          call basout(io,wwte,' ')
          call basout(io,wwte,
-     $'                  Scilab-2.1  ( 10 February 1995 ) ')
+     $'                  Scilab-2.4  (July 12, 1998) ')
          call basout(io,wwte,
-     $'                  Copyright (C) 1989-95 INRIA ')
+     $'                  Copyright (C) 1989-98 INRIA ')
       endif
       return 
       end
