@@ -2,6 +2,7 @@
 c ====================================================================
 c     searches help file and call unix command scihelp 
 c ================================== ( Inria    ) =============
+c     Copyright INRIA
       include '../stack.h'
       integer dot,name,eol,ierr,quote
       character*80 h
@@ -17,27 +18,13 @@ C           argument is a word
             nstr=lpt(4)-lpt(3)+1
             call cvstr(nstr,lin(lpt(3)-1),h,1)
          else
-C           argument is a string 
-            if (sym.eq.0) sym = dot
-            if (sym.eq.quote) then 
-               call getstr
-               if(err.gt.0) return
-               call getsym
-               ilog= getsmat("helpmg",top,top,ms,ns,1,1,lr,nstr)
-               top=top-1
-               call cvstr(min(nstr,80),istk(lr),h,1)
-            endif
+C           argument is a symbol
+            h='symbols'
+            nstr=7
          endif
       endif
-      call xscion(iflag)
-      if(iflag.eq.0) then
-         buf='$SCI/bin/scilab -help "'//h(1:nstr)//'"    '
-         call bashos(buf,26+nstr,ls,ierr)
-      else
-         buf='$SCI/bin/scilab -help "'//h(1:nstr)//
-     $        '" | $SCI/bin/xless &   '
-         call bashos(buf,53+nstr,ls,ierr)
-      endif
+      h(nstr+1:nstr+1)= char(0)
+      call iscihelp(buf,h(1:nstr+1),ierr)
       if(ierr.ne.0) then
          call error(85)
          return
