@@ -2,19 +2,21 @@
 c     ====================================================================
 c     Scilab parsing function
 c     ====================================================================
+c     Copyright INRIA
       include '../stack.h'
       parameter (nz1=nsiz-1,nz2=nsiz-2)
       logical compil,eptover
 c     
       logical iflag
       common /basbrk/ iflag
-      integer semi,equal,eol,lparen,rparen,colon
-      integer blank,comma,left,right,less,great,quote,percen
-      integer name,insert
+      integer semi,equal,eol,lparen,rparen,colon,dot
+      integer blank,comma,left,right,less,great,not
+      integer quote,percen
+      integer name,num,insert,extrac
 c     
       integer id(nsiz),ans(nsiz)
-      integer pts,psym,excnt,p,r
-      integer pcount,strcnt,bcount,qcount
+      integer pts,psym,excnt,p,r,topk
+      integer pcount,strcnt,bcount,qcount,pchar
 c
       integer otimer,ntimer,stimer,ismenu
       external stimer,ismenu
@@ -23,8 +25,9 @@ c
 c     
       data blank/40/,semi/43/,equal/50/,eol/99/,comma/52/,colon/44/
       data lparen/41/,rparen/42/,left/54/,right/55/,less/59/,great/60/
-      data quote/53/,percen/56/
-      data name/1/,insert/2/
+      data not/61/
+      data quote/53/,percen/56/,dot/51/
+      data name/1/,num/0/,insert/2/,extrac/3/
       data ans/672929546,nz1*673720360/
 c     
       save job
@@ -44,7 +47,7 @@ c
       if(pt.gt.0) goto 86
       if(err.gt.0) goto 98
 
-c     initialisation
+c     initialization
 c-------------------
  05   sym = eol
       job=0
@@ -65,8 +68,8 @@ c
       if(comp(1).eq.0) goto 12
       if(lin(lpt(4)+1).eq.eol) goto 88
 c     
-c     acquisition d'un nouvelle ligne
-c-------------------------------------
+c     get a new line
+c-------------------
  12   continue
       if(lct(4).le.-10) then 
          lct(4)=-lct(4)-11      
@@ -87,17 +90,16 @@ c-------------------------------------
          endif
       endif
  13   continue
-      call stsync(1)
       call getlin(job)
       if(fin .eq. -1) then
-c     gestion des lignes suite dans le cas "de l'appel par fortran"
+c     Continuation line handling when scilab is called as a routine
          fun=99
          return
       endif
       job=0
       err = 0
 c     
-c     debut d'un nouveau statement , clause , expr ou command
+c     Beginning of a new statement, clause expression or command
 c------------------------------------------------------------
  15   continue
       if (inxsci.eq.1) then
@@ -120,7 +122,7 @@ c
       excnt = 0
       if(.not.iflag) goto 18
 
-c     gestion des pauses
+c     Handling of pauses
  16   if ( eptover(1,psiz))  goto 98
       pstk(pt)=rio
       ids(2,pt)=top
@@ -134,7 +136,7 @@ c     gestion des pauses
       endif
 c     *call* macro
       goto 88
-c     fin des pauses
+c     pauses termination
  17   rio=pstk(pt)
       top=ids(2,pt)
       pt=pt-1
@@ -156,14 +158,22 @@ c-------------------------
  20   call comand(syn)
       if (err .gt. 0) goto 98
       if (fun .eq. 99) return
+      if (fun .ne. 0) goto 93
       if (fin .lt. 0) goto 80
       if (fin .eq. 2) goto 88
       if (fin .eq. 3) goto 16
       if (fin .eq. 4) goto 05
       if (fin .gt. 0) goto 75
-      rhs = 0
-      fin=0
-      call funtab(syn,fin,1)
+ 21   rhs = 0
+c      fin=0
+c      call funtab(syn,fin,1)
+      fin=-5
+c IL y a p avec fin=-5 (on ne trouve pas les macros parce que l'on ne
+c veut pas que les macros sans arg soient vues comme des commandes
+c mais pourquoi pas il suffirait de dire que pour visualiser une macro
+c il faut faire disp()
+      fun=0
+      call funs(syn)
       if (fin .gt. 0) then
 c        name est le nom d'une primitive
          if(char1.eq.equal) then
@@ -233,8 +243,22 @@ c     looking for equal
             goto 98
          endif
       else if(sym.eq.quote) then
-         if(.not.(psym.le.blank.or.psym.eq.rparen.or.psym.eq.right
-     $        .or.psym.eq.percen.or.psym.eq.quote)) strcnt=1
+c     .  check if transpose or beginning of a string
+         pchar=lin(lpt(3)-2)
+         if(abs(pchar).eq.blank) then
+            strcnt=1
+         elseif(psym.ne.num.and.psym.ne.name.and.psym.ne.rparen.and.
+     $           psym.ne.right.and.psym.ne.dot.and.psym.ne.quote) then
+            strcnt=1
+         endif
+
+c         if(psym.ne.num.and.psym.ne.name.and.psym.ne.rparen.and.
+c     $        psym.ne.right.and.psym.ne.dot.and.psym.ne.quote)
+c     $        strcnt=1
+c         if (bcount.ne.0) then
+c            pchar=lin(lpt(3)-2)
+c            if(abs(pchar).eq.blank) strcnt=1
+c         endif
       else if(sym.eq.left) then
          bcount=bcount+1
       else if(sym.eq.right) then
@@ -252,10 +276,13 @@ c         endif
             if(char1.eq.equal) then
                call getsym
             else
-               if(psym.ne.less.or.psym.ne.great)  goto 32
+               if(psym.ne.less.and.psym.ne.great.and.
+     $              psym.ne.not)  goto 32
             endif
          endif
          if(sym.eq.eol .or. sym.eq.comma .or. sym.eq.semi) goto 50
+c     .  next line for recursive index
+         if(sym.eq.lparen) goto 31
       else if(sym.eq.eol) then
          if(bcount.eq.0) then
             call error(3)
@@ -273,18 +300,22 @@ c         endif
       goto 31
 c     
  32   lpt(4)=lpt(5)
+      icount=0
       char1=lparen
       call getsym
  33   call getsym
       excnt = excnt+1
       if ( eptover(1,psiz)) goto 98
       call putid(ids(1,pt), id)
-      pstk(pt) = excnt
+      pstk(pt) = excnt+1000*icount
       rstk(pt) = 702
 c     *call* expr
       goto 81
- 35   call putid(id,ids(1,pt))
-      excnt = pstk(pt)
+ 35   continue
+
+      call putid(id,ids(1,pt))
+      icount=int(pstk(pt)/1000)
+      excnt = pstk(pt)-1000*icount
       pt = pt-1
       if (sym .eq. comma) goto 33
       if (sym .ne. rparen) then
@@ -292,6 +323,41 @@ c     *call* expr
          if (err .gt. 0) goto 98
       endif
       if (sym .eq. rparen) call getsym
+c     next lines for recursive index
+      if(sym.eq.lparen) then
+
+         if(excnt.gt.1) then
+c           call error(3)
+c           return
+            if(comp(1).eq.0) then
+c     .     form  list with individual indexes
+               call mkindx(0,excnt)
+               if(err.gt.0) return
+            else
+               if (compil(19,0,excnt,0,0)) then 
+                  if (err.gt.0) return
+               endif
+            endif
+            excnt=1
+
+         endif
+         excnt=0
+         icount=icount+1
+         goto 33
+      endif
+      if(icount.gt.0) then
+         if(comp(1).eq.0) then
+c     .     form  list with individual indexes
+            call mkindx(icount+1,excnt)
+            if(err.gt.0) return
+         else
+            if (compil(19,icount+1,excnt,0,0)) then 
+               if (err.gt.0) return
+            endif
+         endif
+         excnt=1
+      endif
+c     end of code for recursive index
       goto 60
 c     
 c     multiple lhs
@@ -331,29 +397,45 @@ c-----------------------
       sym=name
       call putid(syn,id)
       call putid(id,ans)
+      goto 61
 c     
 c     lhs finished, start rhs
+c----------------------------
  60   if (sym .eq. equal) call getsym
-c     call funtab(id,fin,1)
-c     if(fin.ne.0) then
-c     call putid(ids(1,pt+1),id)
-c     call error(25)
-c     return
-c     endif
-      if ( eptover(1,psiz))  goto 98
+c      fun=0
+c      if(sym.eq.name) then
+c     check if name is a function
+c         fin=-2
+c         call funs(syn)
+c      endif
+
+ 61   if ( eptover(1,psiz))  goto 98
       call putid(ids(1,pt),id)
+
       pstk(pt) = excnt
       rstk(pt) = 703
 c     *call* expr
       goto 81
- 65   if (sym.eq.semi .or. sym.eq.comma .or. sym.eq.eol) goto 70
+ 65   continue
+      if (rstk(pt-lhs).eq.313) then 
+c     store  new variable as "named" at the top of the stack
+         if (sym.eq.rparen .or. sym.eq.comma) then
+            call mrknmd()
+            if(err.gt.0) goto 98
+            goto 83
+         else
+            call error(40)
+            goto 98
+         endif
+      endif
+      if (sym.eq.semi .or. sym.eq.comma .or. sym.eq.eol) goto 70
       call error(40)
-      if (err .gt. 0) goto 98
+      goto 98
 c     
 c     store results
 c-------------------
  70   rhs = pstk(pt)
-      if(err1.ne.0) goto 73
+      if(err1.ne.0) goto 74
       if(rhs.eq.0) goto 72
       fin=-3
       call stackg(ids(1,pt))
@@ -363,23 +445,36 @@ c-------------------
       rstk(pt)=704
       fin=insert
 c     *call* allops(insert)
-      goto 93
+      goto 91
  71   lhs=pstk(pt)
  72   call stackp(ids(1,pt),0)
       if (err .gt. 0) goto 98
+c     topk points on the newly saved variable
+      topk=fin
 c     print if required
 c----------------------
-      if(lct(4).lt.0.or.fin.eq.0) goto 73
-      if(sym.ne.semi.and.lct(3).eq.0) then
-         call print(ids(1,pt),fin,wte)
-      else if(sym.eq.semi.and.lct(3).eq.1) then
-         call print(ids(1,pt),fin,wte)
-      endif
+      if(lct(4).lt.0.or.fin.eq.0) goto 74
+      if(.not.((sym.ne.semi.and.lct(3).eq.0).or.
+     &     (sym.eq.semi.and.lct(3).eq.1))) goto 74
+ 73   call print(ids(1,pt),topk,wte)
       if (err .gt. 0) goto 98
+      if(topk.eq.0) goto 74
+c     overloaded display, call a macro
+      if ( eptover(1,psiz))  goto 98
+      rstk(pt)=708
+      pstk(pt)=sym
+      ids(1,pt)=sym
+      if(fun.eq.0) goto 88
+      goto 85
+ 731  continue
+      sym=pstk(pt)
+      pt=pt-1
+      goto 73
 c     
- 73   pt = pt-1
+ 74   pt = pt-1
       lhs = lhs-1
       if (lhs .gt. 0) goto 70
+
 c     
 c     finish statement
 c---------------------
@@ -397,10 +492,14 @@ c---------------------
      +        ' paus:'//buf(21:22))
       endif
       if(err1.ne.0) then
+         if(rstk(pt).eq.502.and.rstk(pt-1).eq.903) then
+c     catched and continue on error in an execstr instruction
+            goto 88
+         endif
          if(err2.eq.0) err2=err1
          err1=0
-         imode=abs(errct/10000)
-         if(imode-4*int(imode/4).eq.2) iflag=.true.
+         imode=abs(errct/100000)
+         if(imode-8*int(imode/8).eq.2) iflag=.true.
       endif
       toperr=top
 c     fin instruction
@@ -431,7 +530,7 @@ c     fin d'une instruction dans une clause
          k=lpt(6)
          if(lin(k-1).eq.eol.and.lin(k).eq.eol) then
             call error(47)
-            if (err .gt. 0) goto 98
+            goto 98
          endif
       endif
       if(lpt(4).eq.lpt(6))  then
@@ -447,40 +546,49 @@ c-----------------------
  80   icall=0
       call clause
       if (err .gt. 0) goto 98
-      goto(81,82,83,93,88,92,15,80,85),icall
+      goto(81,82,83,91,88,90,15,80,85),icall
       if (pt .le. 0) goto 15
       r = rstk(pt)/100
-      goto(81,82,83,93,88,92,95,80,85),r
+      goto(81,82,83,91,88,90,92,80,85),r
       goto 99
 c     
  81   icall=0
       call expr
       if (err .gt. 0) goto 98
-      goto(81,82,83,93,88,92,15,80,85),icall
+      goto(81,82,83,91,88,90,15,80,85),icall
       r = rstk(pt)/100
-      goto(81,82,83,93,88,92,95,80,85),r
+      goto(81,82,83,91,88,90,92,80,85),r
       goto 99
 c     
  82   icall=0
       call terme
       if (err .gt. 0) goto 98
-      goto(81,82,83,93,88,92,15,80,85),icall
+      goto(81,82,83,91,88,90,15,80,85),icall
       r = rstk(pt)/100
-      goto(81,82,83,93,88,92,95,80,85),r
+      goto(81,82,83,91,88,90,92,80,85),r
       goto 99
 c     
  83   icall=0
       call fact
       if (err .gt. 0) goto 98
-      goto(81,82,83,93,88,92,15,80,85),icall
+      goto(81,82,83,91,88,90,15,80,85),icall
       r = rstk(pt)/100
-      goto(81,82,83,93,88,92,95,80,85),r
+      goto(81,82,83,91,88,90,92,80,85),r
       goto 99
 c     
  85   icall=0
       if(err1.ne.0) then
-         if(int(rstk(pt)/100).eq.9) pt=pt-1
-         goto 86
+         if(int(rstk(pt)/100).eq.9) then
+            if(rstk(pt).eq.901.or.rstk(pt).eq.904) then
+c              *call* matfns
+               return
+            elseif(rstk(pt).ne.903) then
+               pt=pt-1
+               goto 86
+            endif
+         else
+            goto 86
+         endif
       endif
 c     compilation matfns: <100*fun rhs lhs fin>
       if (compil(100*fun,rhs,lhs,fin,0)) then 
@@ -491,81 +599,108 @@ c     *call* matfns
          return
       endif
  86   if (err .gt. 0) goto 98
-      goto(81,82,83,93,88,92,15,80,85),icall
+      goto(81,82,83,91,88,90,15,80,85),icall
       r = rstk(pt)/100
-      goto(81,82,83,93,88,92,95,80,85),r
+      goto(81,82,83,91,88,90,92,80,85),r
       goto 99
       
 c     
  88   icall=0
       call macro
       if (err .gt. 0) goto 98
-      goto(81,82,83,93,88,92,10,80,85),icall
+      goto(81,82,83,91,88,90,10,80,85),icall
       r = rstk(pt)/100
-      goto(81,82,83,93,88,92,95,80,85,89),r
+      goto(81,82,83,91,88,90,92,80,85,89),r
       goto 99
  89   fun=99
       return
 c     
- 92   icall=0
+ 90   icall=0
       call  run
       if (err .gt. 0) goto 98
       if (fun .eq. 99) return
-c     le dernier label sert a gerer le retour de abort
-      goto(81,82,83,93,88,92,15,80,85,05),icall
+c     last label is used to handle return from abort
+      goto(81,82,83,91,88,90,15,80,85,05),icall
       r = rstk(pt)/100
-      goto(81,82,83,93,88,92,95,80,85),r
+      goto(81,82,83,91,88,90,92,80,85),r
       goto 99
 c     
- 93   icall=0
+ 91   icall=0
       call allops
       if (err .gt. 0) goto 98
-      goto(81,82,83,93,88,92,15,80,85),icall
+      goto(81,82,83,91,88,90,15,80,85),icall
       r = rstk(pt)/100
-      goto(81,82,83,93,88,92,95,80,85),r
+      goto(81,82,83,91,88,90,92,80,85),r
       goto 99
 c     
- 95   goto(17,35,65,71,86,97) rstk(pt)-700
+ 92   goto(17,35,65,71,65,97,94,731) rstk(pt)-700
       goto 99
 c     
+ 93   continue
+c     command like function and macro call
+      if ( eptover(1,psiz)) goto 98
+      pstk(pt)=1
+      call putid(ids(1,pt),ans)
+      rstk(pt)=707
+      if (fun .gt. 0)  then
+c        *call* matfns
+         goto 85
+      else
+         if (comp(1).ne.0)  then
+            rhs=rhs+1
+            fin=extrac
+c           *call* allops(extrac)
+            goto 91
+         else
+            fin=lstk(fin)
+c           *call* macro
+            goto 88
+         endif
+      endif
+ 94   goto 71
+c
  96   continue
-c     gestion des evements asynchrones "interpretes"
+c     asynchronous events handling
       call getmen(buf,lb,nentry)
-      pt=pt+1
-      pstk(pt)=top
-      call bexec(buf(1:lb),lb,nentry,ierr)
+      call bexec(buf(1:lb),lb,ierr)
       if(ierr.ne.0) goto 15
+      if ( eptover(1,psiz)) goto 98
+      pstk(pt)=top
       rstk(pt)=706
 
 c     *call* macro
       goto 88
- 97   top=pstk(pt)
+ 97   top=pstk(pt)-1
       pt=pt-1
       goto 15
       
  98   continue
-c     recuperation des erreurs
-c-----------------------------
-      imode=abs(errct)/10000
-      imode=imode-4*int(imode/4)
+c     error recovery
+c-------------------
+      imode=abs(errct)/100000
+      imode=imode-8*int(imode/8)
       if(imode.eq.3) then
          fun=99
          return
       endif
 c     
-c     erreur lors d'un external  (niv) ou d'une compilation (comp)
-c     erreur lors d'une pause
+c     error in an external (niv), during compilation (comp) or in a pause
       if(pt.ne.0) then
          if(rstk(pt).eq.503.and.rio.eq.rte) then
             comp(1)=0
             goto 12
          endif
+c     added 16/04/97
+         if(err1.ne.0.and.rstk(pt).eq.502) then
+c     catched error while compiling
+            goto 88
+         endif
       endif
-c     erreur dans un external
+c     error in an external
       if(niv.gt.0) then
          return
       else
-c     erreur dans une pause
+c     error in a  pause
          comp(1)=0
          goto 05
       endif
