@@ -1,17 +1,20 @@
-       subroutine print(id,lk,lunit)
-c     ====================================================================
+      subroutine print(id,lk,lunit)
+c     ==================================================================
+c     ==
 c     print object of id id(nsiz) stored at position lk in the stack
-c     ====================================================================
+c     ==================================================================
+c     ==
+c     Copyright INRIA
       include '../stack.h'
-      integer id(nsiz),lk
+      integer id(nsiz),lk,id1(nsiz)
 c     
       common / ptkeep / lwk
       integer itype,itypel,gettype
-      integer fl,mode,m,n,it,lr,lc,nlr,lkeep,topk,lname
+      integer fl,mode,m,n,it,lr,lc,nlr,lkeep,topk,lname,siz,vol
+      integer namef(nlgh),percent,under,pchar
       logical getmat,ilog,getpoly,typer,clsave,getsimat
-      logical crewimat ,islss,getilist,getbmat
+      logical crewimat ,islss,getilist,getbmat,eptover
       character*4 name
-c$$$      character*(nlgh) mmname
       character*10 form
       character*200 ligne
       integer nclas
@@ -20,16 +23,21 @@ c$$$      character*(nlgh) mmname
       data comma/52/
       data left/54/,right/55/,rparen/42/,lparen/41/,equal/50/
       data eol/99/,nclas/29/
+      data percen/56/,under/36/,pchar/25/
 c     
       iadr(l)=l+l-1
       sadr(l)=(l/2)+1
-c
+c     
       islss=.false.
       lineln=lct(5)
       mode=lct(6)
       ndgt=lct(7)
+      if(rstk(pt).eq.1101) goto 96
 c     
-      if (lct(1) .lt. 0) return
+      if (lct(1) .lt. 0) then
+         lk=0
+         return
+      endif
 c     
       if(id(1).ne.0) call prntid(id,-1,lunit)
  01   nlist=0
@@ -42,9 +50,9 @@ C     topk : free stack zone for working areas
       mactop=0
       if (abs(itype).eq.11.or.abs(itype).eq.13) mactop=1
 c     
- 05   goto (20,10,06,70,25,26,06,06,06,30,80,06,80,90,40,40),abs(itype)
- 06   call msgs(33,lunit)
-      goto 45
+ 05   goto (20,10,06,55,25,26,06,06,06,30,60,06,60,70,40,40,40)
+     $     ,abs(itype)
+ 06   goto 75
 c     
 c     ----polynomial matrices
  10   ilog=getpoly("print",lk,lk,it,m,n,name,namel,ilp,lr,lc)
@@ -59,14 +67,14 @@ C     working area (see dmpdsp)
          call basout(io,lunit,' ')
          if(io.eq.-1) goto 99
          call dmpdsp(stk(lr+istk(ilp)),istk(ilp),m,m,n,name,
-     &       namel,ndgt,mode, lineln,lunit,buf,istk(lw))
+     &        namel,ndgt,mode, lineln,lunit,buf,istk(lw))
          call msgs(35,lunit)
          call basout(io,lunit,' ')
          if(io.eq.-1) goto 99
          call dmpdsp(stk(lc+istk(ilp)),istk(ilp),m,m,n,name,
      &        namel,ndgt,mode,lineln,lunit,buf,istk(lw))
       endif
-      goto 45
+      goto 48
 c     
 c     -------scalar matrices 
  20   ilog=getmat("print",lk,lk,it,m,n,lr,lc)
@@ -74,7 +82,7 @@ C     working area
       if (.not.crewimat("print",topk,1,m*n+2*n,lw)) return
       if(m*n.eq.0) then
          call basout(io,lunit,'     []')
-         goto 45
+         goto 48
       endif
       if(it.eq.0) then 
          call dmdsp(stk(lr),m,m,n,ndgt,mode,lineln,lunit,buf,istk(lw))
@@ -82,7 +90,7 @@ C     working area
          call wmdsp(stk(lr),stk(lc),m,m,n,ndgt,mode,lineln,lunit,
      &        buf,istk(lw))
       endif
-      goto 45 
+      goto 48 
 c     -------sparse scalar matrices 
  25   il=iadr(lstk(lk))
       m=istk(il+1)
@@ -98,7 +106,7 @@ c     -------sparse scalar matrices
          call wspdsp(ne,istk(irc),stk(lr),stk(lr+ne),m,n,ndgt,mode,
      $        lineln,lunit,buf)
       endif
-      goto 45 
+      goto 48 
 c     -------sparse boolean matrices 
  26   il=iadr(lstk(lk))
       m=istk(il+1)
@@ -106,24 +114,69 @@ c     -------sparse boolean matrices
       ne=istk(il+4)
       irc=il+5
       call lspdsp(ne,istk(irc),m,n,ndgt,mode,
-     $        lineln,lunit,buf)
-      goto 45 
+     $     lineln,lunit,buf)
+      goto 48 
 c     -------matrices of string 
  30   ilog=getsimat("print",lk,lk,m,n,1,1,lr,nlr)
 C     working area 
       if (.not.crewimat("print",topk,1,n,lw)) return
       call strdsp(istk(lr),istk(lr-m*n-1),m,n,lineln,lunit,istk(lw),buf)
-      goto 45
+      goto 48
 c     -------lists 
  40   continue
+      itype=gettype(lk)
       call listtype(lk,itypel)
       if (itypel.eq.1) goto 50
-      if (itypel.eq.2) islss=.true.
+      islss=itypel.eq.2
+      if(islss.or.itype.eq.15) goto 45
+ 41   continue
+      ilw=iadr(lstk(lk))
+      if(istk(ilw).lt.0) ilw=iadr(istk(ilw+1))
+      nw=istk(ilw+1)
+      llw=sadr(ilw+3+nw)
+c     form the requested function name
+c     get tlist type
+      iltyp=iadr(llw)
+      nlt=min(nlgh-3,istk(iltyp+5)-1)
+      iltyp=iltyp+5+istk(iltyp+1)*istk(iltyp+2)
+      namef(1)=percen
+      call icopy(nlt,istk(iltyp),1,namef(2),1)
+      namef(2+nlt)=under
+      namef(3+nlt)=pchar
+      call namstr(id1,namef,nlt+3,0)
+c     look for the function 
+      fin=0
+      call funs(id1)
+      if(err.gt.0) return
+      if(fun.gt.0) goto 42
+
+      if(fin.eq.0) goto 45
+
+      fin=-1
+      call stackg(id1)
+      if(fin.eq.0) goto 45
+
+c     copy tlist to top of stack
+ 42   if(lk.ne.top) then
+         top=top+1
+         ilt1=iadr(lstk(top))
+         lt1=sadr(ilt1+3+nw)
+         err=lt1+istk(ilw+2+nw)-lstk(bot)
+         if(err.gt.0) then
+            call error(17)
+            return
+         endif
+         call icopy(nw+3,istk(ilw),1,istk(ilt1),1)
+         call dcopy(istk(ilw+2+nw)-1,stk(llw),1,stk(lt1),1)
+         lstk(top+1)=lt1+istk(ilw+2+nw)-1
+      endif
+      goto 95
+c     
 c     check for typed lists 
-      ilog=getilist("print",lk,lk,nl,1,ilt)
+ 45   ilog=getilist("print",lk,lk,nl,1,ilt)
       illist=lstk(lk)
 C     list ( we must deal with recursion ) 
- 41   nlist=nlist+1
+      nlist=nlist+1
       if(nlist.le.1) then
          if(id(1).ne.0) then
             call cvnamel(id,ligne,1,li1)
@@ -133,35 +186,39 @@ C     list ( we must deal with recursion )
       else
          li1=li2
       endif
-      ligne(li1+1:li1+1)='>'  
+      ligne(li1+1:li1+1)='('  
       if(islss) ligne(li1+1:li1+1)='('
       li1=li1+2
       kl=0
- 43   continue
+ 47   continue
       if(nl.eq.0) call basout(io,lunit,'     ()')
- 45   if(nlist.le.0) goto 99
+ 48   if(nlist.le.0) goto 99
       if(lct(1).lt.0) goto 99
       kl=kl+1
-      if(kl.gt.nl) goto 47
-C ce qui est dessous est plus qu'etrange getilist fair un mvptr et un ptrback
-c la valeur stockee dans ptkeep est ecrasee au secon appel de mvptr et le secon ptrback 
-c ne retourne pas la premiere valeur sauvee mais la seconde..... et pourtant ca marche ?????
+      if(kl.gt.nl) goto 49
+C     ce qui est dessous est plus qu'etrange getilist fair un mvptr et
+c     un ptrback
+c     la valeur stockee dans ptkeep est ecrasee au secon appel de mvptr
+c     et le secon ptrback 
+c     ne retourne pas la premiere valeur sauvee mais la seconde..... et
+c     pourtant ca marche ?????
       call mvptr(topk,illist)
       ilog=getilist("print",topk,topk,nl,kl,ilk)
+      il=iadr(lstk(topk))
+      siz=istk(il+2+kl)-istk(il+2+(kl-1))
       call ptrback(topk)
       lstk(lk)=ilk
       itype=gettype(lk)
 C     if the argument is rational list we must not treat it as a list 
-      if (itype.eq.15.or.itype.eq.16) then 
-c-compat the itype.eq.15 is retained for compatibility
+      if (itype.eq.15.or.itype.eq.16.or.itype.eq.17) then 
+c     -compat the itype.eq.15 is retained for compatibility
          call listtype(lk,itypel)
          if (itypel.ne.1) then 
             if (.not.clsave(topk,illist,kl,li1,nl)) goto 99
          endif
       endif
       fl=int(log10(real(kl+0.1)))+1
-      write(form,103) fl
- 103  format('(i',i3,')')
+      write(form,'(''(i'',i3,'')'')') fl
       if(li1+fl.gt.200) then
          call error(109)
          return
@@ -173,53 +230,59 @@ c-compat the itype.eq.15 is retained for compatibility
       if(io.eq.-1) goto 99
       if(islss) then
          if(kl.eq.1) then
-         call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
-     + ')   (state-space system:)')
-c         ligne(1:li2)=' '
-         call basout(io,lunit,' ')
+            call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
+     +           ')   (state-space system:)')
+c     ligne(1:li2)=' '
+            call basout(io,lunit,' ')
          endif
          if(kl.eq.2) then
-         call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
-     + ') = A matrix = ')
-         call basout(io,lunit,' ')
+            call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
+     +           ') = A matrix = ')
+            call basout(io,lunit,' ')
          endif
          if(kl.eq.3) then
-         call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
-     + ') = B matrix = ')
-         call basout(io,lunit,' ')
+            call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
+     +           ') = B matrix = ')
+            call basout(io,lunit,' ')
          endif
          if(kl.eq.4) then
-         call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
-     + ') = C matrix = ')
-         call basout(io,lunit,' ')
+            call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
+     +           ') = C matrix = ')
+            call basout(io,lunit,' ')
          endif
          if(kl.eq.5) then
-         call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
-     + ') = D matrix = ')
-         call basout(io,lunit,' ')
+            call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
+     +           ') = D matrix = ')
+            call basout(io,lunit,' ')
          endif
          if(kl.eq.6) then
-         call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
-     + ') = X0 (initial state) = ')
-         call basout(io,lunit,' ')
+            call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
+     +           ') = X0 (initial state) = ')
+            call basout(io,lunit,' ')
          endif
          if(kl.eq.7) then
-         call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
-     + ') = Time domain = ')
-         call basout(io,lunit,' ')
+            call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2)//
+     +           ') = Time domain = ')
+            call basout(io,lunit,' ')
          endif
       else
+         ligne(li2+1:li2+1)=')'
+         li2=li2+1
          call basout(io,lunit,buf(1:nlist+6)//ligne(1:li2))
          call basout(io,lunit,' ')
       endif
       if(io.eq.-1) goto 99
+      if(siz.le.0) then
+         call basout(io,lunit,'    Undefined')
+         goto 48
+      endif
       goto 05
 c     end for list 
- 47   continue
+ 49   continue
       nlist=nlist-1
       if(nlist.le.0) goto 99
       call clrest(topk,illist,kl,li1,nl)
-      goto 43
+      goto 47
 c     
 c     -----fractions rationnelles <=> list('r',matpoly,matpoly)
  50   continue
@@ -230,11 +293,11 @@ c     ---local change of lstk(topk)
       ivtn=gettype(topk)
       typer=.false.
       if ( ivtn.eq.1) then 
-         ilog=getmat("print",topk,topk,it,m,n,lrn,lcn)
+         ilog=getmat("print",topk,topk,itnum,m,n,lrn,lcn)
          lrn=lrn-1
          lcn=lcn-1
       elseif ( ivtn.eq.2) then 
-         ilog=getpoly("print",topk,topk,it,m,n,name,
+         ilog=getpoly("print",topk,topk,itnum,m,n,name,
      $        namel,ilpn,lrn,lcn)
       else 
          typer=.true.
@@ -246,32 +309,34 @@ c     denominateur (3ieme elt )
       call mvptr(topk,ild)
       ivtd=gettype(topk)
       if ( ivtd.eq.1) then 
-         ilog=getmat("print",topk,topk,it,m1,n1,lrd,lcd)
+         ilog=getmat("print",topk,topk,itden,m1,n1,lrd,lcd)
          lrd=lrd-1
          lcd=lcd-1
       elseif ( ivtd.eq.2) then 
-         ilog=getpoly("print",topk,topk,it,m1,n1,name,
+         ilog=getpoly("print",topk,topk,itden,m1,n1,name,
      $        namel,ilpd,lrd,lcd)
       else 
          typer=.true.
       endif 
       call ptrback(topk)
+      if(itnum.ne.0.or.itden.ne.0) goto 41
+
 C     --wrong type argument or not same size 
       if (typer.or.m1.ne.m.or.n1.ne.n) then 
          call cvname(id,buf(1:nlgh),1)
          call error(103)
          return 
       endif 
-C	if num or den are scalar matrix we fill a working array 
-C       with 1:m*n+1 (by creating a bmat),in which we can store integers
-C       it's a trick to give a proper argument 
-C       to dmrdsp which will treat the scalar matrix as a polynomial 
-C       matrix of degre 0 
+C     if num or den are scalar matrix we fill a working array 
+C     with 1:m*n+1 (by creating a bmat),in which we can store integers
+C     it's a trick to give a proper argument 
+C     to dmrdsp which will treat the scalar matrix as a polynomial 
+C     matrix of degre 0 
       if ( ivtn.eq.1.or.ivtd.eq.1) then 
          if (.not.crewimat("print",topk,1,m*n+1,idb)) return
-         do 11 k=0,m*n
+         do 51 k=0,m*n
             istk(idb+k) =k+1
- 11      continue 
+ 51      continue 
          if (ivtn.eq.1) ilpn=idb
          if (ivtd.eq.1) ilpd=idb
       endif 
@@ -286,19 +351,19 @@ C     of requested size iws
       call dmrdsp(stk(lrn+istk(ilpn)),istk(ilpn),stk(lrd+istk(ilpd)),
      $     istk(ilpd),m,m,n,name,
      $     namel,ndgt,mode,lineln,lunit,buf, istk(lw))
-      goto 45
+      goto 48
 c     
 c     -----------boolean matrix
- 70   ilog= getbmat("print",lk,lk,m,n,lr)
+ 55   ilog= getbmat("print",lk,lk,m,n,lr)
       if(m*n.eq.0) then
          call basout(io,lunit,'     []')
       else
          call dldsp(istk(lr),m,m,n,lineln,lunit,buf)
       endif
-      goto 45
+      goto 48
 c     
 c     ------------macros---- a changer 
- 80   continue
+ 60   continue
       il=iadr(lstk(lk))
       l=istk(il+1)
       if(istk(il).lt.0) il=iadr(lstk(l))
@@ -306,24 +371,24 @@ c     ------------macros---- a changer
       l=1
       is1=left
       is2=right
-      do 85 i=1,2
+      do 64 i=1,2
          n=istk(il+1)
          il=il+1
          buf(l:l)=alfa(is1+1)
          l=l+1
          if (n.ne.0) then
-            do 83 j=1,n
+            do 63 j=1,n
                call cvnamel(istk(il+1),buf(l:),1,lname)
                l=l+lname
                buf(l:l)=alfa(comma+1)
                l=l+1
                il=il+nsiz
- 83         continue
+ 63         continue
             l=l-1
          endif	
          buf(l:l)=alfa(is2+1)
          l=l+1
-         if(i.eq.2) goto 85
+         if(i.eq.2) goto 64
          buf(l:l)=alfa(equal+1)
          l=l+1
          if(mactop.eq.1) then
@@ -335,7 +400,7 @@ c     ------------macros---- a changer
          endif
          is1=lparen
          is2=rparen
- 85   continue
+ 64   continue
       il=il+1
       l=l-1
       call basout(io,wte,buf(1:l))
@@ -344,45 +409,47 @@ c     ------------macros---- a changer
       il=il+1
 C     cas ou l'object macro est au top ( pas ds une liste )
       if (mactop.eq.1) then 
-c$$$c        compiled macro [ display of source code ]
-c$$$         if(istk(ilm).eq.13) then 
-c$$$            call cvnamel(idstk(1,lk),mmname,1,lname)
-c$$$            call xscion(iflag)
-c$$$            if(iflag.eq.0) then
-c$$$               buf='$SCI/bin/scilab -macro "'//mmname(1:lname)//'"  '
-c$$$               call bashos(buf,27+lname,ls,ierr)
-c$$$            else
-c$$$               buf='$SCI/bin/scilab -macro "'//mmname(1:lname)//
-c$$$     $              '" | $SCI/bin/xless &   '
-c$$$               call bashos(buf,45+lname,ls,ierr)
-c$$$            endif
-c$$$            goto 89 
-c$$$         endif
-C     we supress the display of the code of a non compiled macro with goto 89
+c$$$  c        compiled macro [ display of source code ]
+c$$$  if(istk(ilm).eq.13) then 
+c$$$  call cvnamel(idstk(1,lk),mmname,1,lname)
+c$$$  call xscion(iflag)
+c$$$  if(iflag.eq.0) then
+c$$$  buf='$SCI/bin/scilab -macro "'//mmname(1:lname)//'"  '
+c$$$  call bashos(buf,27+lname,ls,ierr)
+c$$$  else
+c$$$  buf='$SCI/bin/scilab -macro "'//mmname(1:lname)//
+c$$$  $              '" | $SCI/bin/xless &   '
+c$$$  call bashos(buf,45+lname,ls,ierr)
+c$$$  endif
+c$$$  goto 68 
+c$$$  endif
+C     we supress the display of the code of a non compiled macro with
+c     goto 68
          isncf=1
-         if (isncf.eq.1) goto 89
+         if (isncf.eq.1) goto 68
          l=il
- 86      if(istk(l).eq.eol) goto 87
+ 65      if(istk(l).eq.eol) goto 66
          l=l+1
-         goto 86
- 87      if(istk(l+1).eq.eol) goto 89
+         goto 65
+ 66      if(istk(l+1).eq.eol) goto 68
          n=l-il
          nl=lct(5)
-         do 88 i1=1,n,nl
+         do 67 i1=1,n,nl
             i2=min(n,i1+nl-1)-i1+1
             call cvstr(i2,istk(il+i1-1),buf,1)
             call basout(io,wte,buf(1:i2))
             if(io.eq.-1) goto 99
- 88      continue
+ 67      continue
          il=l+1
          l=il
-         goto 86
+         goto 65
       endif
- 89   il=ilm
-      goto 45
+ 68   il=ilm
+      goto 48
+
 c     ------------library-- a changer aussi 
 C     [14,n,codagedupath(n),nombre-de-nom,nclas+1 cases,suite des noms]
- 90   illib=iadr(lstk(lk))
+ 70   illib=iadr(lstk(lk))
       n=istk(illib+1)
       illib=illib+2
       call cvstr(n,istk(illib),buf,1)
@@ -391,10 +458,89 @@ C     [14,n,codagedupath(n),nombre-de-nom,nclas+1 cases,suite des noms]
       n=istk(illib)
       illib=illib+nclas+2
       call prntid(istk(illib),n,lunit)
-      goto 45
+      goto 48
+c     
+c     ----------- other variables type (overloaded)
+ 75   continue
+c     form the requested function name %%%%
+      namef(1)=percen
+      call typ2cod(iadr(lstk(lk)),namef(2),nlt)
+      namef(2+nlt)=under
+      namef(3+nlt)=pchar
+      call namstr(id1,namef,nlt+3,0)
+c     look for the function 
+      fin=0
+      call funs(id1)
+      if(err.gt.0) return
+      if(fun.gt.0) goto 76
+
+      if(fin.eq.0) goto 48
+
+      fin=-1
+      call stackg(id1)
+      if(fin.eq.0) goto 48
+
+c     copy variable  to top of stack
+ 76   if(lk.ne.top) then
+         top=top+1
+         vol=lstk(lk+1)-lstk(lk)
+         call dcopy(vol,stk(lstk(lk)),1,stk(lstk(top)),1)
+         lstk(top+1)=lstk(top)+vol
+      endif
+      goto 95
+
 c     -----------end
+
+c     overloaded print
+ 95   continue
+
+c     preserve data for recursion
+
+      if ( eptover(2,psiz)) return
+      rstk(pt-1)= 0
+      ids(1,pt-1)= lhs
+      ids(2,pt-1)= rhs
+      ids(3,pt-1)= lstk(lk)
+      lstk(lk)   = lkeep
+      pstk(pt)   = lk
+      ids(1,pt)  = nlist
+      ids(2,pt)  = kl
+      ids(3,pt)  = nl
+      ids(4,pt)  = illist
+      ids(5,pt)  = topk
+      rstk(pt)   = 1101
+      lhs=1
+      rhs=1
+      if(fun.eq.0) then
+         fin=lstk(fin)
+         icall=5
+c     *call* macro
+         return
+      else
+c     *call* matfn
+         return
+      endif
+
+ 96   continue
+c     set back preserved data
+      lhs     = ids(1,pt-1)
+      rhs     = ids(2,pt-1)
+      lk      = pstk(pt)
+      lkeep   = lstk(lk)
+      lstk(lk)= ids(3,pt-1)
+      nlist   = ids(1,pt)
+      kl      = ids(2,pt)
+      nl      = ids(3,pt)
+      illist  = ids(4,pt)
+      topk    = ids(5,pt)
+      pt=pt-2
+      if(lk.ne.top) top=top-1
+      goto 48
+
+
  99   continue
       lstk(lk)=lkeep
+      lk=0
       return
       end
 
@@ -428,14 +574,14 @@ c     -----------end
 
       subroutine listtype(lk,itype)
       include '../stack.h'
-c      implicit undefined (a-z)
+c     implicit undefined (a-z)
       integer rat,gettype
       logical ilog,getilist,getsmat
 c     return itype=0 for list, itype=1 for rat, itype=2 for lss
 c     check for typed lists 
       integer nl,ilt,itype,topk,lk,mt,nt,ilc,nlr
       data rat/27/
-c
+c     
       itype=0
       topk=lk
       ilog=getilist("print",lk,lk,nl,1,ilt)
