@@ -1,26 +1,21 @@
       subroutine tradsl(kmac,illist,nlist)
 c     
 c!but 
-c     traduction des macros compilees pour changement de syntaxe
-c     subroutine inspiree de run
-c!listed'appel
-c     
-c     tradsl prend la macro compilee dans la pile scilab
-c     entree :
-c     lunit  : etiquette logique du fichier dans le quel on veut ecrire
-c     le nouveau texte de la macro
-c     kmak  : numero de la variable scilab qui contient le code de la macro
-c     variable scilab 
+c     convert compiled macros to lst structure
+c!calling sequence
+c     subroutine tradsl(kmac,illist,nlist)
+c     kmac  : variable number of the compiled macro in the scilab stack
 c!    
 c
 c
+c     Copyright INRIA
       include '../stack.h'
 c     
       integer nops
-      parameter (nops=30)
+      parameter (nops=32)
       character*40 strg
       character*40 form
-      double precision x
+      double precision x,xx
       integer op,ix(2),fptr
       equivalence (x,ix(1))
       logical iflag
@@ -40,8 +35,8 @@ c                            +  -  * .*  *. .*.  / ./  /. ./.
       data (ops(i),i=1,10) /45,46,47,98,200,149,48,99,201,150/
 c                            \ .\   \. .\. ** =  <  >  <=  >=  <>
       data (ops(i),i=11,21)/49,100,202,151,62,50,59,60,109,110,119/
-c                             : [,] ins ext  '  [;]  |  &   ~
-      data (ops(i),i=22,nops) /44,01, 02 ,03 ,53, 04, 57, 58, 61/
+c                             : [,] ins ext '  [;]  | &   ~  .^  .'
+      data (ops(i),i=22,nops)/44,01, 02 ,03,53,04, 57,58, 61,113,104/
 c
       iadr(l)=l+l-1
       sadr(l)=(l/2)+1
@@ -153,13 +148,14 @@ c     nouvelle 'operation'
       op=istk(lc)
 c     
       if(ddt.lt.-1) write(6,'(i7)') op
-      goto(20,25,40,42,30,41,45,50,50,60,15,90,90,90,90,100) ,op
+      goto(20,25,40,42,30,41,45,50,50,60,15,90,90,90,90,100,
+     &     12,101,102,90) ,op
 c     
 c     
 c     matfns
       if(op.ge.100)   goto 80
 c     
-      if(op.ne.99) then
+ 12   if(op.ne.99) then
          call error(44)
          return
       endif
@@ -274,6 +270,11 @@ c     type 5
 c     op
       ii=0
  31   ii=ii+1
+      if(ii.gt.nops) then
+         buf='Unmanaged operation'
+         call error(999)
+         return
+      endif
       if(ops(ii).ne.istk(lc+1)) goto 31
       call intstr(ii,istk(l),ni,1)
 c      call intstr(istk(lc+1),istk(l),ni,1)
@@ -334,17 +335,7 @@ c
       isign=1
       if(x.lt.0)  isign=-1
       call fmt(abs(x),maxc,ifmt,n1,n2)
-      if(ifmt.eq.1) then
-         nf=1
-         ifl=maxc
-         n2=1
-         write(form,130) maxc,maxc-7
-         write(strg,form) x
-      elseif(ifmt.ge.0) then
-         nf=2
-         write(form,120) n1,n2
-         write(strg,form) x
-      elseif(ifmt.eq.-1) then
+      if(ifmt.eq.-1) then
 c     Inf
          ifl=3
          strg='Inf'
@@ -352,16 +343,42 @@ c     Inf
 c     Nan
          ifl=3
          strg='Nan'
+      elseif(ifmt.eq.1) then
+         nf=1
+         ifl=maxc
+         n2=1
+         if(abs(x).ge.1.d100.or.abs(x).lt.1.d-99) then
+            ie=int(log10(abs(x)))
+            if(ie.lt.0) ie=ie-1
+            xx=x/(10.0d0**ie)
+            nf=2
+            write(form,120) maxc,0
+            write(strg,form) xx
+            ls=lnblnk(strg)
+            write(strg(ls+1:),'(''D'',i4)') ie
+         else
+            write(form,130) maxc,maxc-7
+            write(strg,form) x
+         endif
+      elseif(ifmt.ge.0) then
+         nf=2
+         write(form,120) n1,n2
+         write(strg,form) x
       endif
       i1=0
  410  i1=i1+1
       if(strg(i1:i1).eq.' ') goto 410
+
       i2=lnblnk(strg)+1
- 420  i2=i2-1
-      if(i2.gt.2) then
-         if(strg(i2:i2).eq.'0') goto 420
+      if(ifmt.ge.0.and.ifmt.ne.1) then
+ 420     i2=i2-1
+         if(i2.gt.2) then
+            if(strg(i2:i2).eq.'0') goto 420
+         endif
+         if(strg(i2:i2).eq.'.') i2=i2-1
+      else
+         i2=i2-1
       endif
-      if(strg(i2:i2).eq.'.') i2=i2-1
 
       istk(il)=10
       istk(il+1)=1
@@ -427,7 +444,7 @@ c     on cree les premiers elements de la liste "for"
       istk(il)=15
       istk(il+1)=3
       istk(il+2)=1
-      lr=sadr(il+5)
+      lr=sadr(il+6)
       ilr=il+3
 c
       il=iadr(lr)
@@ -623,6 +640,11 @@ c     type 5
 c     op
       ii=0
  52   ii=ii+1
+      if(ii.gt.nops) then
+         buf='Unmanaged operation'
+         call error(999)
+         return
+      endif
       if(ops(ii).ne.istk(lc0+1)) goto 52
       call intstr(ii,istk(l),ni,1)
       istk(il+6)=istk(il+5)+ni
@@ -984,9 +1006,69 @@ c
 c     info sur numero de lignes
       lc=lc+2
       goto 10
+c
+ 101  continue
+c     mark named variable
+      il=iadr(lr)
+      istk(il)=10
+      istk(il+1)=1
+      istk(il+2)=2
+      istk(il+3)=0
+      istk(il+4)=1
+      l=il+7
+c     type 18
+      istk(l)=1
+      istk(l+1)=8
+      istk(il+5)=3
+      l=l+2
+c     nom de la variable
+      call namstr(istk(lc+1),istk(l),ni,1)
+      istk(il+6)=istk(il+5)+ni
+      l=l+ni
+c     
+      l=sadr(l)
+      istk(ilr)=istk(ilr-1)+l-lr
+      lr=l
+      ilr=ilr+1
+c     
+      lc=lc+1+nsiz
+      goto 10
+ 102  continue
+c     mkindx
+      il=iadr(lr)
+      istk(il)=10
+      istk(il+1)=1
+      istk(il+2)=3
+      istk(il+3)=0
+      istk(il+4)=1
+      l=il+9
+c     type 2
+      istk(l)=1
+      istk(l+1)=9
+      istk(il+5)=3
+      l=l+2
+
+c     n
+      call intstr(istk(lc+1),istk(l),ni,1)
+      istk(il+6)=istk(il+5)+ni
+      l=l+ni
+c     m
+      call intstr(istk(lc+2),istk(l),ni,1)
+      istk(il+8)=istk(il+7)+ni
+      l=l+ni
+c
+      l=sadr(l)
+      istk(ilr)=istk(ilr-1)+l-lr
+      lr=l
+      ilr=ilr+1
+c
+      lc=lc+3
+      goto 10
+
       
   120 format('(f',i2,'.',i2,')')
   130 format('(1pd',i2,'.',i2,')')
 
 c     
       end
+
