@@ -4,9 +4,11 @@
 "Xscilab*vpane.msWindow.min:20",
 "Xscilab*vpane.msWindow.logoWindow.borderWidth:0",
 "Xscilab*vpane.msWindow.messageWindow.fromHoriz:logoWindow",
+"Xscilab*font:7x13",
 "Xscilab*vpane.commandWindow.*.Cursor: left_ptr",
 "Xscilab*vpane.commandWindow.allowResize: true",
 "Xscilab*vpane.commandWindow.showGrip:False",
+"Xscilab*vpane.commandWindow.ButMenuS*font:7x13",
 "Xscilab*vpane.commandWindow.ButMenuS.label:File",
 "Xscilab*vpane.commandWindow.ButMenuS.MenuS.File.label:File Operations",
 "Xscilab*vpane.commandWindow.ButMenuS.MenuS.Quit.label:Quit",
@@ -35,48 +37,48 @@
 "Xscilab*SimpleMenu*Sme.height:	16",
 "Xscilab*SimpleMenu*Cursor: left_ptr",
 "Xscilab*vpane.Vtsci.font:		9x15",
-"Xscilab*vpane.Vtsci.font1:		9x13",
+"Xscilab*vpane.Vtsci.font1:		7x13",
 "Xscilab*vpane.Vtsci.saveLines:	1024",
 "Xscilab*vpane.Vtsci.scrollBar:	on",
 "Xscilab*vpane.Vtsci.min:200",
-"Xscilab*vpane.Vtsci.mainMenu.Label:  Main Options",
-"Xscilab*vpane.Vtsci.mainMenu*redraw*Label:  Redraw Window",
-"Xscilab*vpane.Vtsci.vtMenu.Label:  VT Options",
-"Xscilab*vpane.Vtsci.vtMenu*scrollbar*Label:  Enable Scrollbar",
-"Xscilab*vpane.Vtsci.vtMenu*jumpscroll*Label:  Enable Jump Scroll",
-"Xscilab*vpane.Vtsci.vtMenu*reversevideo*Label:  Enable Reverse Video",
-"Xscilab*vpane.Vtsci.vtMenu*autowrap*Label:  Enable Auto Wraparound",
-"Xscilab*vpane.Vtsci.vtMenu*reversewrap*Label:  Enable Reverse Wraparound",
-"Xscilab*vpane.Vtsci.vtMenu*autolinefeed*Label:  Enable Auto Linefeed",
-"Xscilab*vpane.Vtsci.vtMenu*appcursor*Label:  Enable Application Cursor Keys",
-"Xscilab*vpane.Vtsci.vtMenu*appkeypad*Label:  Enable Application Keypad",
-"Xscilab*vpane.Vtsci.vtMenu*scrollkey*Label:  Scroll to Bottom on Key Press",
-"Xscilab*vpane.Vtsci.vtMenu*scrollttyoutput*Label:  Scroll to Bottom on Tty Output",
-"Xscilab*vpane.Vtsci.vtMenu*allow132*Label: Allow 80/132 Column Switching",
-"Xscilab*vpane.Vtsci.vtMenu*cursesemul*Label:  Enable Curses Emulation",
-"Xscilab*vpane.Vtsci.vtMenu*visualbell*Label:  Enable Visual Bell",
-"Xscilab*vpane.Vtsci.vtMenu*marginbell*Label:  Enable Margin Bell",
-"Xscilab*vpane.Vtsci.vtMenu*altscreen*Label:  Show Alternate Screen",
-"Xscilab*vpane.Vtsci.vtMenu*softreset*Label:  Do Soft Reset",
-"Xscilab*vpane.Vtsci.vtMenu*hardreset*Label:  Do Full Reset",
-"Xscilab*vpane.Vtsci.vtMenu*clearsavedlines*Label:  Reset and Clear Saved Lines",
-"Xscilab*vpane.Vtsci.vtMenu*vthide*Label:  Hide VT Window",
-"Xscilab*vpane.Vtsci.fontMenu.Label:  VT Fonts",
-"Xscilab*vpane.Vtsci.fontMenu*fontdefault*Label:	Default",
-"Xscilab*vpane.Vtsci.fontMenu*font1*Label:	Unreadable",
-"Xscilab*vpane.Vtsci.font1:		9x13",
-"Xscilab*vpane.Vtsci.fontMenu*font2*Label:	Tiny",
-"Xscilab*vpane.Vtsci.font2:		5x7",
-"Xscilab*vpane.Vtsci.fontMenu*font3*Label:	Small",
-"Xscilab*vpane.Vtsci.font3:		6x10",
-"Xscilab*vpane.Vtsci.fontMenu*font4*Label:	Medium",
-"Xscilab*vpane.Vtsci.font4:		7x13",
-"Xscilab*vpane.Vtsci.fontMenu*font5*Label:	Large",
-"Xscilab*vpane.Vtsci.font5:		9x15",
-"Xscilab*vpane.Vtsci.fontMenu*font6*Label:	Huge",
-"Xscilab*vpane.Vtsci.font6:		10x20",
-"Xscilab*vpane.Vtsci.fontMenu*fontescape*Label:	Escape Sequence",
-"Xscilab*vpane.Vtsci.fontMenu*fontsel*Label:		Selection",
+"Xscilab*mainMenu.Label:  Main Options",
+"Xscilab*mainMenu*redraw*Label:  Redraw Window",
+"Xscilab*vtMenu.Label:  VT Options",
+"Xscilab*vtMenu*scrollbar*Label:  Enable Scrollbar",
+"Xscilab*vtMenu*jumpscroll*Label:  Enable Jump Scroll",
+"Xscilab*vtMenu*reversevideo*Label:  Enable Reverse Video",
+"Xscilab*vtMenu*autowrap*Label:  Enable Auto Wraparound",
+"Xscilab*vtMenu*reversewrap*Label:  Enable Reverse Wraparound",
+"Xscilab*vtMenu*autolinefeed*Label:  Enable Auto Linefeed",
+"Xscilab*vtMenu*appcursor*Label:  Enable Application Cursor Keys",
+"Xscilab*vtMenu*appkeypad*Label:  Enable Application Keypad",
+"Xscilab*vtMenu*scrollkey*Label:  Scroll to Bottom on Key Press",
+"Xscilab*vtMenu*scrollttyoutput*Label:  Scroll to Bottom on Tty Output",
+"Xscilab*vtMenu*allow132*Label: Allow 80/132 Column Switching",
+"Xscilab*vtMenu*cursesemul*Label:  Enable Curses Emulation",
+"Xscilab*vtMenu*visualbell*Label:  Enable Visual Bell",
+"Xscilab*vtMenu*marginbell*Label:  Enable Margin Bell",
+"Xscilab*vtMenu*altscreen*Label:  Show Alternate Screen",
+"Xscilab*vtMenu*softreset*Label:  Do Soft Reset",
+"Xscilab*vtMenu*hardreset*Label:  Do Full Reset",
+"Xscilab*vtMenu*clearsavedlines*Label:  Reset and Clear Saved Lines",
+"Xscilab*vtMenu*vthide*Label:  Hide VT Window",
+"Xscilab*fontMenu.Label:  VT Fonts",
+"Xscilab*fontMenu*fontdefault*Label:	Default",
+"Xscilab*fontMenu*font1*Label:	Unreadable",
+"Xscilab*font1:		7x13",
+"Xscilab*fontMenu*font2*Label:	Tiny",
+"Xscilab*font2:		5x7",
+"Xscilab*fontMenu*font3*Label:	Small",
+"Xscilab*font3:		6x10",
+"Xscilab*fontMenu*font4*Label:	Medium",
+"Xscilab*font4:		7x13",
+"Xscilab*fontMenu*font5*Label:	Large",
+"Xscilab*font5:		9x15",
+"Xscilab*fontMenu*font6*Label:	Huge",
+"Xscilab*font6:		10x20",
+"Xscilab*fontMenu*fontescape*Label:	Escape Sequence",
+"Xscilab*fontMenu*fontsel*Label:		Selection",
 "Xscilab*helpShell.x:10",
 "Xscilab*helpShell.y:20",
 "Xscilab*helpShell.minHeight:300",
@@ -105,16 +107,23 @@
 "Xscilab*helpShell.helpForm*Text*borderWidth:	1",
 "Xscilab*helpShell.helpForm*Label*resizable:	True",
 "Xscilab*helpShell.helpForm*helpLabel.borderWidth:	0",
+"Xscilab*helpShell.helpForm*helpLabel.width:		600",
+"Xscilab*helpShell.helpForm*helpLabel.top:		chaintop",
+"Xscilab*helpShell.helpForm*helpLabel.bottom:		chaintop",
+"Xscilab*helpShell.helpForm*helpLabel.right:		chainright",
+"Xscilab*helpShell.helpForm*helpLabel.left:		chainleft",
+"Xscilab*helpShell.helpForm*helpLabel.height:		30",
+"Xscilab*helpShell.helpForm*helpViewport.top:		chaintop",
 "Xscilab*helpShell.helpForm*helpViewport.fromVert:	helpLabel",
 "Xscilab*helpShell.helpForm*helpViewport.width:	650",
 "Xscilab*helpShell.helpForm*helpViewport.height:	250",
 "Xscilab*helpShell.helpForm*helpViewport.left:	chainLeft",
-"Xscilab*helpShell.helpForm*helpViewport.right:	chainLeft",
+"Xscilab*helpShell.helpForm*helpViewport.right:	chainRight",
 "Xscilab*helpShell.helpForm*helpViewport1.fromVert:	helpViewport",
 "Xscilab*helpShell.helpForm*helpViewport1.width:	650",
 "Xscilab*helpShell.helpForm*helpViewport1.height:220",
 "Xscilab*helpShell.helpForm*helpViewport1.left:	chainLeft",
-"Xscilab*helpShell.helpForm*helpViewport1.right:	chainLeft",
+"Xscilab*helpShell.helpForm*helpViewport1.right:	chainRight",
 "Xscilab*helpShell.helpForm*helpViewport1.bottom:	chainBottom",
 "Xscilab*helpShell.helpForm*helpList.font:*-fixed-medium-r-*-*-13-*-*-*-*-*-iso8859-*",
 "Xscilab*helpShell.helpForm*helpList.verticalList:		true",
@@ -138,6 +147,8 @@
 	<BtnDown>,<BtnUp>:	help-done() \\n",
 "Xscilab*helpShell.helpForm.aproposLabel.label:		Apropos:",
 "Xscilab*helpShell.helpForm.aproposLabel.fromVert:	helpDoneButton",
+"Xscilab*helpShell.helpForm.aproposLabel.top:		chainbottom",
+"Xscilab*helpShell.helpForm.aproposLabel.bottom:		chainbottom",
 "Xscilab*helpShell.helpForm.aproposText.top:		chainbottom",
 "Xscilab*helpShell.helpForm.aproposText.bottom:		chainbottom",
 "Xscilab*helpShell.helpForm.aproposText.width:		410",
@@ -149,6 +160,13 @@
 	<Enter>:	display-caret(True) \\n\
 	<Leave>:	display-caret(False) \\n\
 	<Key>Return:	query-apropos() \\n",
+"Xscilab*helpShell.helpForm.aproposInfo.top:		chainbottom",
+"Xscilab*helpShell.helpForm.aproposInfo.bottom:		chainbottom",
+"Xscilab*helpShell.helpForm.aproposInfo.width:		410",
+"Xscilab*helpShell.helpForm.aproposInfo.height:		30",
+"Xscilab*helpShell.helpForm.aproposInfo.fromHoriz:	aproposLabel",
+"Xscilab*helpShell.helpForm.aproposInfo.fromVert:	aproposText",
+"Xscilab*helpShell.helpForm.aproposInfo.label:		",
 "Xscilab*TransientShell*font:*-fixed-medium-r-*-*-13-*-*-*-*-*-iso8859-*",
 "Xscilab*TransientShell.x:						147",
 "Xscilab*TransientShell.y:						20",
@@ -162,25 +180,24 @@
 "Xscilab*TransientShell.hpaned.paned.*showGrip:				False",
 "Xscilab*TransientShell.hpaned.paned.internalBorderWidth:		1",
 "Xscilab*TransientShell.hpaned.paned.Viewport.allowVert:			True",
-"Xscilab*TransientShell.hpaned.paned.Viewport.allowVert:			True",
-"Xscilab*TransientShell.hpaned.paned.Viewport.allowHoriz:			True",
+"Xscilab*TransientShell.hpaned.paned.Viewport.allowHoriz:		True",
 "Xscilab*TransientShell.hpaned.paned.Viewport.forceBars:			False",
 "Xscilab*TransientShell.hpaned.paned.Viewport.vertical.width:		10",
 "Xscilab*TransientShell.hpaned.paned.Viewport.horizontal.height:		10",
 "Xscilab*TransientShell.hpaned.paned.Viewport.borderWidth:		10",
 "Xscilab*TransientShell.hpaned.paned.Viewport.Label.borderWidth:		0",
-"Xscilab*TransientShell.hpaned.paned.Viewport.Label.internalWidth: 		10",
-"Xscilab*TransientShell.hpaned.paned.Viewport.Label.internalHeight:		10",
-"Xscilab*TransientShell.hpaned.paned.Viewport.List.internalWidth:		15",
-"Xscilab*TransientShell.hpaned.paned.Viewport.List.internalHeight:		10",
+"Xscilab*TransientShell.hpaned.paned.Viewport.Label.internalWidth: 	10",
+"Xscilab*TransientShell.hpaned.paned.Viewport.Label.internalHeight:	10",
+"Xscilab*TransientShell.hpaned.paned.Viewport.List.internalWidth:	15",
+"Xscilab*TransientShell.hpaned.paned.Viewport.List.internalHeight:	10",
 "Xscilab*TransientShell.hpaned.paned.Viewport.List.verticalList:		True",
-"Xscilab*TransientShell.hpaned.paned.Viewport.List.defaultColumns:		1",
+"Xscilab*TransientShell.hpaned.paned.Viewport.List.defaultColumns:	1",
 "Xscilab*TransientShell.hpaned.paned.Viewport.List.forceColumns:		True",
-"Xscilab*TransientShell.hpaned.paned.Viewport.List.maxSelectable: 		1",
-"Xscilab*TransientShell.hpaned.paned.Viewport.List.rowSpacing: 			2",
-"Xscilab*TransientShell.hpaned.paned*Text.bottomMargin:				7",
-"Xscilab*TransientShell.hpaned.paned*Text.leftMargin:				7",
-"Xscilab*TransientShell.hpaned.paned*Text*Scrollbar.thickness: 			7",
+"Xscilab*TransientShell.hpaned.paned.Viewport.List.maxSelectable: 	1",
+"Xscilab*TransientShell.hpaned.paned.Viewport.List.rowSpacing: 		2",
+"Xscilab*TransientShell.hpaned.paned*Text.bottomMargin:			7",
+"Xscilab*TransientShell.hpaned.paned*Text.leftMargin:			7",
+"Xscilab*TransientShell.hpaned.paned*Text*Scrollbar.thickness: 		7",
 "Xscilab*TransientShell.hpaned.paned*Text.resizable: 				True",
 "Xscilab*TransientShell.hpaned.paned*Text*editType: 				edit",
 "Xscilab*TransientShell.hpaned.paned*Text.scrollVertical: 			whenNeeded",
@@ -203,9 +220,9 @@
 "Xscilab*chooseShell.hpaned.paned.listviewport.list:1 2 3",
 "Xscilab*chooseShell.hpaned.paned.cform.formVert:			listviewport",
 "Xscilab*dialogShell.title:					Scilab Dialog Panel",
-"Xscilab*chooseShell.hpaned.paned.labelviewport.max:			300",
+"Xscilab*dialogShell.hpaned.paned.labelviewport.max:			300",
 "Xscilab*dialogShell.hpaned.paned.ascii.fromVert:			labelviewport",
-"Xscilab*chooseShell.hpaned.paned.ascii.max:				500",
+"Xscilab*dialogShell.hpaned.paned.ascii.max:				500",
 "Xscilab*dialogShell.hpaned.paned.cform.fromVert:				ascii",
 "Xscilab*dialogShell.hpaned.paned.cform.cancel.fromHoriz:       		ok",
 "Xscilab*choiceShell.title:						Scilab Toggles Panel",
@@ -244,6 +261,10 @@
 "Xscilab*mtdialogShell.hpaned.paned.cform.ok.label:				Ok",
 "Xscilab*mtdialogShell.hpaned.paned.cform.cancel.fromHoriz:			ok",
 "Xscilab*mtdialogShell.hpaned.paned.cform.cancel.label:				Cancel",
+"Xscilab*xsci_file_menu.hpaned.paned.labelviewport.allowResize:			True",
+"Xscilab*xsci_file_menu.hpaned.paned.labelviewport.max:				300",
+"Xscilab*xsci_file_menu.hpaned.paned.labelviewport.min:				100",
+"Xscilab*xsci_file_menu.hpaned.paned.labelviewport.label.resizable:		True",
 "Xscilab*printShell.title:						Scilab Output Selection Panel",
 "Xscilab*printShell.hpaned.paned.form.orientation:				horizontal",
 "Xscilab*printShell.hpaned.paned.form.label.top:					chainTop",
@@ -260,12 +281,17 @@
 "Xscilab*printShell.hpaned.paned.fileform.filelabel.label: 			Filename\\nwithout extension",
 "Xscilab*printShell.hpaned.paned.fileform.filelabel.borderWidth:			0",
 "Xscilab*printShell.hpaned.paned.fileform.ascii.fromHoriz:			filelabel",
+"Xscilab*printShell.hpaned.paned.fileform.ascii.translations:#override\\n\
+	<Enter>:	display-caret(True) \\n\
+	<Leave>:	display-caret(False) \\n\
+	<Key>Return:	go-print() \\n",
 "Xscilab*printShell.hpaned.paned.cform.ok.label:					Ok",
 "Xscilab*printShell.hpaned.paned.cform.cancel.fromHoriz:				ok",
 "Xscilab*printShell.hpaned.paned.cform.cancel.label:				Cancel",
 "Xscilab*scigForm.showGrip:False",
 "Xscilab*scigForm.min:20",
 "Xscilab*scigForm.scigraphicinfo.width:600",
+"Xscilab*scigForm*font:7x13",
 "Xscilab*scigForm.File.fromVert:scigraphicinfo",
 "Xscilab*scigForm.File.Label:File",
 "Xscilab*scigForm.Zoom.fromVert:scigraphicinfo",
@@ -282,6 +308,8 @@
 "Xscilab*scigForm.scigraphic.fromVert:File",
 "Xscilab.color.borderWidth:0",
 "Xscilab.color.internalWidth:0",
+"Xscilab.color*background:white",
+"Xscilab.color*foreground:black",
 "Xscilab.color.background:lightblue",
 "Xscilab.color*scigraphic.background:white",
 "Xscilab.color*scigraphic.foreground:black",
@@ -303,22 +331,22 @@
 "Xscilab.color.vpane.Box.Form.background:blue",
 "Xscilab.gray.borderWidth:0",
 "Xscilab.gray.internalWidth:0",
-"Xscilab.gray.background:gray10",
+"Xscilab.gray.background:grey20",
 "Xscilab.gray*scigraphic.background:white",
 "Xscilab.gray*scigraphic.foreground:black",
-"Xscilab.gray*Form.background:gray5",
-"Xscilab.gray*Label.background:gray10",
-"Xscilab.gray*Label.foreground:black",
-"Xscilab.gray*Command.background:gray5",
-"Xscilab.gray*Command.foreground:black",
+"Xscilab.gray*Form.background:gray25",
+"Xscilab.gray*Label.background:gray35",
+"Xscilab.gray*Label.foreground:white",
+"Xscilab.gray*Command.background:gray40",
+"Xscilab.gray*Command.foreground:white",
 "Xscilab.gray*Box.background:gray10",
 "Xscilab.gray*Toggle.background:gray5",
-"Xscilab.gray*Toggle.foreground:black",
-"Xscilab.gray*MenuButton.background:gray5",
-"Xscilab.gray*MenuButton.foreground:black",
-"Xscilab.gray*SimpleMenu.background:gray5",
-"Xscilab.gray*SimpleMenu.foreground:black",
-"Xscilab.gray*SmeBSB.foreground:black",
-"Xscilab.gray*Scrollbar.background:gray8",
+"Xscilab.gray*Toggle.foreground:white",
+"Xscilab.gray*MenuButton.background:gray40",
+"Xscilab.gray*MenuButton.foreground:white",
+"Xscilab.gray*SimpleMenu.background:gray40",
+"Xscilab.gray*SimpleMenu.foreground:white",
+"Xscilab.gray*SmeBSB.foreground:white",
+"Xscilab.gray*Scrollbar.background:gray10",
 "Xscilab.gray*Paned.internalBorderColor:gray10",
 "Xscilab.gray.vpane.Box.Form.background:gray20",
