@@ -1,3 +1,4 @@
+/* Copyright (C) 1998 Chancelier Jean-Philippe */
 
 /*
  * xarchie : An X browser interface to Archie
@@ -34,7 +35,7 @@ extern void abort();
 
 #include "h_display.h"
 
-#include "h_help.h"
+#include "../sun/h_help.h"
 
 /*	-	-	-	-	-	-	-	-	*/
 /*
