@@ -1,3 +1,4 @@
+/* Copyright (C) 1998 Chancelier Jean-Philippe */
 #ifdef SYSV
 #include <string.h>
 #else
@@ -7,11 +8,21 @@
 #include "x_ptyxP.h"
 #include "x_data.h"
 #include "../machine.h"
+#include "All-extern-x.h"
+#include "All-extern.h"
 /* 
    write_scilab set a scilab command to be executed and displayed at prompt time
    works only with xsci interface
 */
 
+static void str_to_xterm ( string, nbytes)
+    register char *string;
+    int nbytes;
+{
+    register TScreen *screen = &term->screen;
+    StringInput(screen,string,strlen(string));
+}
+
 void write_scilab(s)
     char   *s;
 {
@@ -23,12 +34,6 @@ void write_scilab(s)
 	printf("asynchronous actions are not supported with -nw option\n");
 }
 
-str_to_xterm ( string, nbytes)
-    register char *string;
-    int nbytes;
-{
-    register TScreen *screen = &term->screen;
-    StringInput(screen,string,strlen(string));
-}
+
 
 
