@@ -26,11 +26,17 @@ char     cur_filename[FSIZE];
 
 #include <malloc.h>
 
-extern void Rescan();
+#include "../machine.h"
+#include "All-extern.h"
+#include "../menusX/men_scilab.h"
+
 extern Boolean	file_msg_is_popped;
 extern Widget	file_msg_popup;
 Boolean	warnexist=True;
 
+static void file_panel_dismiss  _PARAMS((void));  
+static void file_panel_cancel  _PARAMS((Widget w, XButtonEvent *ev));  
+
 /* don't allow newlines in text until we handle multiple line texts */
 String		text_translations =
 	"<Key>Return: no-op(RingBell)\n\
@@ -77,8 +83,9 @@ Widget		file_panel,	/* so w_dir can access the scrollbars */
 		file_selfile,	/* selected file widget */
 		file_mask,	/* mask widget */
 		file_dir,	/* current directory widget */
-		file_flist,	/* file list wiget */
-		file_dlist;	/* dir list wiget */
+		file_flist,	/* file list widget */
+		file_dlist,	/* dir list widget */
+                labelW;         /* popup label */
 
 static void
 file_panel_dismiss()
@@ -142,16 +149,14 @@ do_exec(w, ev)
  * Used with the primitive C2F(xgetfile)
  ***********************************/
 
-int
-ok_file(dir,file)
+void ok_file(dir,file)
      char           *file;
      char *dir;
 {
   write_getfile(dir,file);
-  return(0);
 }
 
-ok_end()
+void ok_end()
 {
   /* Accelerators to their default values */
   XtOverrideTranslations(file_selfile,
@@ -169,12 +174,20 @@ ok_end()
 static String	file_name_translations1 =
 	"<Key>Return: ok()\n";
 
-ok_prep(filemask,dirname,flag,err)
+void ok_prep(filemask,dirname,title,flag,err)
      char *filemask;
      char *dirname;
+     char *title;
      int flag,*err;
 {
   char newdir[PATH_MAX];
+  if (file_popup) {
+/*    FirstArg(XtNtitle, title);
+    SetValues(file_popup);	*/
+      FirstArg(XtNlabel, title);
+      SetValues(labelW);
+  }
+
   /* Change Accelerators to ok */
   XtOverrideTranslations(file_selfile,
 			 XtParseTranslationTable(file_name_translations1));
@@ -202,7 +215,7 @@ ok_prep(filemask,dirname,flag,err)
 	{
 	  strcpy(newdir,dirname);
 	}
-      if ( DoChangeDir(newdir) == 1) { *err=1; return;} 
+      DoChangeDir(newdir); 
     }
   XtSetSensitive(ok,True);
   XtSetSensitive(exec, False);
@@ -214,10 +227,9 @@ ok_prep(filemask,dirname,flag,err)
 
 /* make the full path from SCI/partialpath */
 
-parsescipath(path,longpath)
-  char *path,*longpath;
+void parsescipath(path,longpath)
+     char *path,*longpath;
 {
-  char *p;
   strcpy(longpath,getenv("SCI"));
   if (strlen(path)==3)		/* nothing after the SCI, we have the full path */
     return;
@@ -245,14 +257,16 @@ do_ok(w, ev)
 	if (emptyname_msg(fval, "OK"))
 	    return;
 
-	if (change_directory(dval) == 0) {
-	    if (ok_file(dval,fval) == 0) {
-		FirstArg(XtNlabel, fval);
-		SetValues(cfile_text);		/* set the current filename */
-		if (fval != cur_filename)
-			update_cur_filename(fval);	/* and update cur_filename */
-		file_panel_dismiss();
-	    }
+	if (change_directory(dval) == 0) 
+	  {
+	    ok_file(dval,fval);
+	    /** if (ok_file(dval,fval) == 0) { **/
+	      FirstArg(XtNlabel, fval);
+	      SetValues(cfile_text);		/* set the current filename */
+	      if (fval != cur_filename)
+		update_cur_filename(fval);	/* and update cur_filename */
+	      file_panel_dismiss();
+	    /* } */
 	}
     } else {
 	(void) ok_file("",cur_filename);
@@ -514,8 +528,9 @@ file_panel_cancel(w, ev)
 
 
 
-popup_file_panel(w)
+void popup_file_panel(w,description)
     Widget	    w;
+     char* description;
 {
     extern Atom     wm_delete_window;
 
@@ -524,10 +539,12 @@ popup_file_panel(w)
     XtSetSensitive(w, False);
 
     if (!file_popup)
-	create_file_panel(w);
-    else
-      Rescan((Widget) 0, (XEvent*) 0, (String*) 0, (Cardinal*) 0);
-
+	create_file_panel(w,description);
+    else{
+	Rescan((Widget) 0, (XEvent*) 0, (String*) 0, (Cardinal*) 0);
+	FirstArg(XtNlabel, description);
+	SetValues(labelW);
+    }
     XtPopup(file_popup, XtGrabNonexclusive);
     (void) XSetWMProtocols(XtDisplay(file_popup), XtWindow(file_popup),
 			   &wm_delete_window, 1);
@@ -536,16 +553,18 @@ popup_file_panel(w)
     reset_wf_cursor();
 }
 
-create_file_panel(w)
-	Widget		   w;
-{
-  int ch;
+void create_file_panel(w,description)
+     Widget		   w;
+     char *description;
+    {
+	int ch;
 	Widget		   file, beside, below;
+        Widget             hpaned,dialogpanned,viewportW/*,labelW*/;
         XFontStruct     *temp_font;
 	static int	   actions_added=0;
 	file_w = w;
 	XtTranslateCoords(w, (Position) 0, (Position) 0, &xposn, &yposn);
-
+	
 	FirstArg(XtNx, xposn);
 	NextArg(XtNy, yposn + 50);
 	NextArg(XtNtitle, " File menu");
@@ -553,10 +572,22 @@ create_file_panel(w)
 					transientShellWidgetClass,
 					w_toplevel, Args, ArgCount);
 	XtOverrideTranslations(file_popup,
-			   XtParseTranslationTable(file_translations));
+			       XtParseTranslationTable(file_translations));
+	
+        hpaned = XtCreateManagedWidget("hpaned",panedWidgetClass,file_popup,
+				       (Arg *) NULL,(Cardinal)ZERO);
+	
+        dialogpanned = XtCreateManagedWidget("paned",panedWidgetClass,hpaned,
+					     (Arg *) NULL,(Cardinal)ZERO);
+
+	viewportW = XtCreateManagedWidget("labelviewport",viewportWidgetClass,
+					  dialogpanned,(Arg *) NULL,(Cardinal)ZERO);
+	FirstArg(XtNlabel, description);
+	labelW=XtCreateManagedWidget("label",labelWidgetClass,viewportW,Args, ArgCount);
+
 
 	file_panel = XtCreateManagedWidget("file_panel", formWidgetClass,
-					   file_popup, (Arg *) NULL, (Cardinal) 0);
+					   dialogpanned, (Arg *) NULL, (Cardinal) 0);
 
 	FirstArg(XtNlabel, " Current Filename:");
 	NextArg(XtNvertDistance, 15);
