@@ -13,16 +13,21 @@
 #include "wf_fig.h"
 #include "wf_figx.h"
 #include "wf_resources.h"
-static  TOOLSW	msg_form, msg_panel, name_panel;
+static  Widget	msg_form, msg_panel, name_panel;
 #include "wf_mode.h"
 #include "wf_w_util.h"
 #include "wf_w_setup.h"
+
+#include "../machine.h"
+#include "All-extern.h"
+
+
+
+#ifdef __STDC__
+#include <stdarg.h>
+#else
 #include <varargs.h>
-
-/********************* EXPORTS *******************/
-
-int		put_msg();
-int		init_msgreceiving();
+#endif 
 
 /************************  LOCAL ******************/
 
@@ -31,9 +36,9 @@ static char	prompt[BUF_SIZE];
 
 DeclareStaticArgs(12);
 
-int
-init_msg(tool,vert_w, ch,filename)
-     TOOL	    tool,vert_w;
+
+void init_msg(tool,vert_w, ch,filename)
+     Widget	    tool,vert_w;
      int ch;
     char	   *filename;
 {
@@ -76,7 +81,7 @@ init_msg(tool,vert_w, ch,filename)
  * width of the name_panel to get the new width of the message panel
  */
 
-update_cur_filename(newname)
+void update_cur_filename(newname)
 	char	*newname;
 {
 	Dimension namwid;
@@ -104,21 +109,29 @@ update_cur_filename(newname)
 	XtManageChild(msg_form);
 }
 
-/*VARARGS0*/
-int put_msg(va_alist) va_dcl
-{
-    va_list ap;
-    char *format;
 
-    va_start(ap);
-    format = va_arg(ap, char *);
-    vsprintf(prompt, format, ap );
-    va_end(ap);
-    FirstArg(XtNstring, prompt);
-    SetValues(msg_panel);
+#ifdef __STDC__ 
+void  put_msg(char *fmt,...) 
+#else 
+/*VARARGS0*/
+void  put_msg(va_alist) va_dcl
+#endif 
+{
+  va_list ap;
+#ifdef __STDC__
+  va_start(ap,fmt);
+#else
+  char *fmt;
+  va_start(ap);
+  fmt = va_arg(ap, char *);
+#endif
+  vsprintf(prompt, fmt, ap );
+  va_end(ap);
+  FirstArg(XtNstring, prompt);
+  SetValues(msg_panel);
 }
 
-clear_message()
+void clear_message()
 {
     FirstArg(XtNstring, "\0");
     SetValues(msg_panel);
