@@ -65,7 +65,7 @@ DeleteWindow(w, event, params, num_params)
     String *params;
     Cardinal *num_params;
 {
-  C2F(clearexit)(0);
+  ClearExit(0);
 }
 
 XtActionsRec actionProcs[] = {
@@ -122,7 +122,7 @@ Widget w;
 XtPointer call_data, client_data;
 {
     fprintf(stdout, "Button Selected.\n");
-    popup_file_panel(w);
+    popup_file_panel(w,"File Menu");
 
 }
 
