@@ -29,25 +29,15 @@ then
 else
 	echo "$1" NO EXAMPLE >> $LOGFILE
 fi
-
+echo "for k=winsid(),xdel(k);end" >> prov
 echo '' >> prov
+
 }
 
-for j in 1 2 3 4 5 6 7 8
+for j in arma control dcd elementary graphics linear metanet nonlinear polynomials programming robust scicos signal sound tdcs translation
 do
-	echo -n "Processing Man-Part1/man$j "
-	for f in $SCI/man/Man-Part1/man$j/*.$j
-	do
-		echo -n '.'
-		do_example $f
-	done
-	echo ""
-done
-
-for j in 1 2 3 4 5
-do
-	echo -n "Processing Man-Part2/man$j "
-	for f in $SCI/man/Man-Part2/man$j/*.$j
+	echo -n "Processing man/$j "
+	for f in $SCI/man/$j/*.man
 	do
 		echo -n '.'
 		do_example $f
